# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: grid/v1/tensorboard_service.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database

# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()

from google.api import annotations_pb2 as google_dot_api_dot_annotations__pb2
from google.protobuf import timestamp_pb2 as google_dot_protobuf_dot_timestamp__pb2

from grid.protos.grid.v1 import metadata_pb2 as grid_dot_v1_dot_metadata__pb2
from grid.protos.grid.v1 import tensorboard_pb2 as grid_dot_v1_dot_tensorboard__pb2

DESCRIPTOR = _descriptor.FileDescriptor(
    name='grid/v1/tensorboard_service.proto',
    package='grid.v1',
    syntax='proto3',
    serialized_options=b'Z0github.com/gridai/grid/grid-backend/apis/grid/v1',
    create_key=_descriptor._internal_create_key,
    serialized_pb=
    b'\n!grid/v1/tensorboard_service.proto\x12\x07grid.v1\x1a\x1cgoogle/api/annotations.proto\x1a\x16grid/v1/metadata.proto\x1a\x19grid/v1/tensorboard.proto\x1a\x1fgoogle/protobuf/timestamp.proto\"R\n\x18\x43reateTensorboardRequest\x12\x36\n\x0btensorboard\x18\x01 \x01(\x0b\x32\x14.grid.v1.TensorboardR\x0btensorboard\"S\n\x19\x43reateTensorboardResponse\x12\x36\n\x0btensorboard\x18\x01 \x01(\x0b\x32\x14.grid.v1.TensorboardR\x0btensorboard\"\'\n\x15GetTensorboardRequest\x12\x0e\n\x02id\x18\x01 \x01(\tR\x02id\"P\n\x16GetTensorboardResponse\x12\x36\n\x0btensorboard\x18\x01 \x01(\x0b\x32\x14.grid.v1.TensorboardR\x0btensorboard\"\xef\x02\n\x17ListTensorboardsRequest\x12%\n\x0e\x63ontinue_token\x18\x01 \x01(\tR\rcontinueToken\x12)\n\x10resource_version\x18\x02 \x01(\tR\x0fresourceVersion\x12\x14\n\x05limit\x18\x03 \x01(\x03R\x05limit\x12\x17\n\x07user_id\x18\x04 \x01(\tR\x06userId\x12\x1d\n\ncluster_id\x18\x05 \x01(\tR\tclusterId\x12\x41\n\x0e\x63reated_before\x18\x06 \x01(\x0b\x32\x1a.google.protobuf.TimestampR\rcreatedBefore\x12\x34\n\x08phase_in\x18\x07 \x03(\x0e\x32\x19.grid.v1.TensorboardStateR\x07phaseIn\x12;\n\x0cphase_not_in\x18\x08 \x03(\x0e\x32\x19.grid.v1.TensorboardStateR\nphaseNotIn\"\xa4\x01\n\x18ListTensorboardsResponse\x12\x36\n\x0btensorboard\x18\x01 \x03(\x0b\x32\x14.grid.v1.TensorboardR\x0btensorboard\x12%\n\x0e\x63ontinue_token\x18\x02 \x01(\tR\rcontinueToken\x12)\n\x10resource_version\x18\x03 \x01(\tR\x0fresourceVersion\"R\n\x18UpdateTensorboardRequest\x12\x36\n\x0btensorboard\x18\x01 \x01(\x0b\x32\x14.grid.v1.TensorboardR\x0btensorboard\"S\n\x19UpdateTensorboardResponse\x12\x36\n\x0btensorboard\x18\x01 \x01(\x0b\x32\x14.grid.v1.TensorboardR\x0btensorboard\"X\n\x1eUpdateTensorboardStatusRequest\x12\x36\n\x0btensorboard\x18\x01 \x01(\x0b\x32\x14.grid.v1.TensorboardR\x0btensorboard\"Y\n\x1fUpdateTensorboardStatusResponse\x12\x36\n\x0btensorboard\x18\x01 \x01(\x0b\x32\x14.grid.v1.TensorboardR\x0btensorboard\"R\n\x18\x44\x65leteTensorboardRequest\x12\x36\n\x0btensorboard\x18\x01 \x01(\x0b\x32\x14.grid.v1.TensorboardR\x0btensorboard\"S\n\x19\x44\x65leteTensorboardResponse\x12\x36\n\x0btensorboard\x18\x01 \x01(\x0b\x32\x14.grid.v1.TensorboardR\x0btensorboard\"\xc9\x02\n\x18WatchTensorboardsRequest\x12)\n\x10resource_version\x18\x01 \x01(\tR\x0fresourceVersion\x12\x14\n\x05limit\x18\x02 \x01(\x03R\x05limit\x12\x17\n\x07user_id\x18\x04 \x01(\tR\x06userId\x12\x1d\n\ncluster_id\x18\x05 \x01(\tR\tclusterId\x12\x41\n\x0e\x63reated_before\x18\x06 \x01(\x0b\x32\x1a.google.protobuf.TimestampR\rcreatedBefore\x12\x34\n\x08phase_in\x18\x07 \x03(\x0e\x32\x19.grid.v1.TensorboardStateR\x07phaseIn\x12;\n\x0cphase_not_in\x18\x08 \x03(\x0e\x32\x19.grid.v1.TensorboardStateR\nphaseNotIn\"\xab\x01\n\x19WatchTensorboardsResponse\x12)\n\x10resource_version\x18\x01 \x01(\tR\x0fresourceVersion\x12+\n\x04type\x18\x02 \x01(\x0e\x32\x17.grid.v1.WatchEventTypeR\x04type\x12\x36\n\x0btensorboard\x18\x03 \x01(\x0b\x32\x14.grid.v1.TensorboardR\x0btensorboard2\xfc\x06\n\x12TensorboardService\x12|\n\x11\x43reateTensorboard\x12!.grid.v1.CreateTensorboardRequest\x1a\".grid.v1.CreateTensorboardResponse\" \x82\xd3\xe4\x93\x02\x1a\"\x15/v1/core/tensorboards:\x01*\x12u\n\x0eGetTensorboard\x12\x1e.grid.v1.GetTensorboardRequest\x1a\x1f.grid.v1.GetTensorboardResponse\"\"\x82\xd3\xe4\x93\x02\x1c\x12\x1a/v1/core/tensorboards/{id}\x12v\n\x10ListTensorboards\x12 .grid.v1.ListTensorboardsRequest\x1a!.grid.v1.ListTensorboardsResponse\"\x1d\x82\xd3\xe4\x93\x02\x17\x12\x15/v1/core/tensorboards\x12\x96\x01\n\x11UpdateTensorboard\x12!.grid.v1.UpdateTensorboardRequest\x1a\".grid.v1.UpdateTensorboardResponse\":\x82\xd3\xe4\x93\x02\x34\x1a//v1/core/tensorboards/{tensorboard.metadata.id}:\x01*\x12l\n\x17UpdateTensorboardStatus\x12\'.grid.v1.UpdateTensorboardStatusRequest\x1a(.grid.v1.UpdateTensorboardStatusResponse\x12\x93\x01\n\x11\x44\x65leteTensorboard\x12!.grid.v1.DeleteTensorboardRequest\x1a\".grid.v1.DeleteTensorboardResponse\"7\x82\xd3\xe4\x93\x02\x31*//v1/core/tensorboards/{tensorboard.metadata.id}\x12\\\n\x11WatchTensorboards\x12!.grid.v1.WatchTensorboardsRequest\x1a\".grid.v1.WatchTensorboardsResponse0\x01\x42\x32Z0github.com/gridai/grid/grid-backend/apis/grid/v1b\x06proto3',
    dependencies=[
        google_dot_api_dot_annotations__pb2.DESCRIPTOR,
        grid_dot_v1_dot_metadata__pb2.DESCRIPTOR,
        grid_dot_v1_dot_tensorboard__pb2.DESCRIPTOR,
        google_dot_protobuf_dot_timestamp__pb2.DESCRIPTOR,
    ]
)

_CREATETENSORBOARDREQUEST = _descriptor.Descriptor(
    name='CreateTensorboardRequest',
    full_name='grid.v1.CreateTensorboardRequest',
    filename=None,
    file=DESCRIPTOR,
    containing_type=None,
    create_key=_descriptor._internal_create_key,
    fields=[
        _descriptor.FieldDescriptor(
            name='tensorboard',
            full_name='grid.v1.CreateTensorboardRequest.tensorboard',
            index=0,
            number=1,
            type=11,
            cpp_type=10,
            label=1,
            has_default_value=False,
            default_value=None,
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            json_name='tensorboard',
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key
        ),
    ],
    extensions=[],
    nested_types=[],
    enum_types=[],
    serialized_options=None,
    is_extendable=False,
    syntax='proto3',
    extension_ranges=[],
    oneofs=[],
    serialized_start=160,
    serialized_end=242,
)

_CREATETENSORBOARDRESPONSE = _descriptor.Descriptor(
    name='CreateTensorboardResponse',
    full_name='grid.v1.CreateTensorboardResponse',
    filename=None,
    file=DESCRIPTOR,
    containing_type=None,
    create_key=_descriptor._internal_create_key,
    fields=[
        _descriptor.FieldDescriptor(
            name='tensorboard',
            full_name='grid.v1.CreateTensorboardResponse.tensorboard',
            index=0,
            number=1,
            type=11,
            cpp_type=10,
            label=1,
            has_default_value=False,
            default_value=None,
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            json_name='tensorboard',
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key
        ),
    ],
    extensions=[],
    nested_types=[],
    enum_types=[],
    serialized_options=None,
    is_extendable=False,
    syntax='proto3',
    extension_ranges=[],
    oneofs=[],
    serialized_start=244,
    serialized_end=327,
)

_GETTENSORBOARDREQUEST = _descriptor.Descriptor(
    name='GetTensorboardRequest',
    full_name='grid.v1.GetTensorboardRequest',
    filename=None,
    file=DESCRIPTOR,
    containing_type=None,
    create_key=_descriptor._internal_create_key,
    fields=[
        _descriptor.FieldDescriptor(
            name='id',
            full_name='grid.v1.GetTensorboardRequest.id',
            index=0,
            number=1,
            type=9,
            cpp_type=9,
            label=1,
            has_default_value=False,
            default_value=b"".decode('utf-8'),
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            json_name='id',
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key
        ),
    ],
    extensions=[],
    nested_types=[],
    enum_types=[],
    serialized_options=None,
    is_extendable=False,
    syntax='proto3',
    extension_ranges=[],
    oneofs=[],
    serialized_start=329,
    serialized_end=368,
)

_GETTENSORBOARDRESPONSE = _descriptor.Descriptor(
    name='GetTensorboardResponse',
    full_name='grid.v1.GetTensorboardResponse',
    filename=None,
    file=DESCRIPTOR,
    containing_type=None,
    create_key=_descriptor._internal_create_key,
    fields=[
        _descriptor.FieldDescriptor(
            name='tensorboard',
            full_name='grid.v1.GetTensorboardResponse.tensorboard',
            index=0,
            number=1,
            type=11,
            cpp_type=10,
            label=1,
            has_default_value=False,
            default_value=None,
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            json_name='tensorboard',
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key
        ),
    ],
    extensions=[],
    nested_types=[],
    enum_types=[],
    serialized_options=None,
    is_extendable=False,
    syntax='proto3',
    extension_ranges=[],
    oneofs=[],
    serialized_start=370,
    serialized_end=450,
)

_LISTTENSORBOARDSREQUEST = _descriptor.Descriptor(
    name='ListTensorboardsRequest',
    full_name='grid.v1.ListTensorboardsRequest',
    filename=None,
    file=DESCRIPTOR,
    containing_type=None,
    create_key=_descriptor._internal_create_key,
    fields=[
        _descriptor.FieldDescriptor(
            name='continue_token',
            full_name='grid.v1.ListTensorboardsRequest.continue_token',
            index=0,
            number=1,
            type=9,
            cpp_type=9,
            label=1,
            has_default_value=False,
            default_value=b"".decode('utf-8'),
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            json_name='continueToken',
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key
        ),
        _descriptor.FieldDescriptor(
            name='resource_version',
            full_name='grid.v1.ListTensorboardsRequest.resource_version',
            index=1,
            number=2,
            type=9,
            cpp_type=9,
            label=1,
            has_default_value=False,
            default_value=b"".decode('utf-8'),
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            json_name='resourceVersion',
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key
        ),
        _descriptor.FieldDescriptor(
            name='limit',
            full_name='grid.v1.ListTensorboardsRequest.limit',
            index=2,
            number=3,
            type=3,
            cpp_type=2,
            label=1,
            has_default_value=False,
            default_value=0,
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            json_name='limit',
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key
        ),
        _descriptor.FieldDescriptor(
            name='user_id',
            full_name='grid.v1.ListTensorboardsRequest.user_id',
            index=3,
            number=4,
            type=9,
            cpp_type=9,
            label=1,
            has_default_value=False,
            default_value=b"".decode('utf-8'),
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            json_name='userId',
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key
        ),
        _descriptor.FieldDescriptor(
            name='cluster_id',
            full_name='grid.v1.ListTensorboardsRequest.cluster_id',
            index=4,
            number=5,
            type=9,
            cpp_type=9,
            label=1,
            has_default_value=False,
            default_value=b"".decode('utf-8'),
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            json_name='clusterId',
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key
        ),
        _descriptor.FieldDescriptor(
            name='created_before',
            full_name='grid.v1.ListTensorboardsRequest.created_before',
            index=5,
            number=6,
            type=11,
            cpp_type=10,
            label=1,
            has_default_value=False,
            default_value=None,
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            json_name='createdBefore',
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key
        ),
        _descriptor.FieldDescriptor(
            name='phase_in',
            full_name='grid.v1.ListTensorboardsRequest.phase_in',
            index=6,
            number=7,
            type=14,
            cpp_type=8,
            label=3,
            has_default_value=False,
            default_value=[],
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            json_name='phaseIn',
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key
        ),
        _descriptor.FieldDescriptor(
            name='phase_not_in',
            full_name='grid.v1.ListTensorboardsRequest.phase_not_in',
            index=7,
            number=8,
            type=14,
            cpp_type=8,
            label=3,
            has_default_value=False,
            default_value=[],
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            json_name='phaseNotIn',
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key
        ),
    ],
    extensions=[],
    nested_types=[],
    enum_types=[],
    serialized_options=None,
    is_extendable=False,
    syntax='proto3',
    extension_ranges=[],
    oneofs=[],
    serialized_start=453,
    serialized_end=820,
)

_LISTTENSORBOARDSRESPONSE = _descriptor.Descriptor(
    name='ListTensorboardsResponse',
    full_name='grid.v1.ListTensorboardsResponse',
    filename=None,
    file=DESCRIPTOR,
    containing_type=None,
    create_key=_descriptor._internal_create_key,
    fields=[
        _descriptor.FieldDescriptor(
            name='tensorboard',
            full_name='grid.v1.ListTensorboardsResponse.tensorboard',
            index=0,
            number=1,
            type=11,
            cpp_type=10,
            label=3,
            has_default_value=False,
            default_value=[],
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            json_name='tensorboard',
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key
        ),
        _descriptor.FieldDescriptor(
            name='continue_token',
            full_name='grid.v1.ListTensorboardsResponse.continue_token',
            index=1,
            number=2,
            type=9,
            cpp_type=9,
            label=1,
            has_default_value=False,
            default_value=b"".decode('utf-8'),
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            json_name='continueToken',
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key
        ),
        _descriptor.FieldDescriptor(
            name='resource_version',
            full_name='grid.v1.ListTensorboardsResponse.resource_version',
            index=2,
            number=3,
            type=9,
            cpp_type=9,
            label=1,
            has_default_value=False,
            default_value=b"".decode('utf-8'),
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            json_name='resourceVersion',
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key
        ),
    ],
    extensions=[],
    nested_types=[],
    enum_types=[],
    serialized_options=None,
    is_extendable=False,
    syntax='proto3',
    extension_ranges=[],
    oneofs=[],
    serialized_start=823,
    serialized_end=987,
)

_UPDATETENSORBOARDREQUEST = _descriptor.Descriptor(
    name='UpdateTensorboardRequest',
    full_name='grid.v1.UpdateTensorboardRequest',
    filename=None,
    file=DESCRIPTOR,
    containing_type=None,
    create_key=_descriptor._internal_create_key,
    fields=[
        _descriptor.FieldDescriptor(
            name='tensorboard',
            full_name='grid.v1.UpdateTensorboardRequest.tensorboard',
            index=0,
            number=1,
            type=11,
            cpp_type=10,
            label=1,
            has_default_value=False,
            default_value=None,
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            json_name='tensorboard',
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key
        ),
    ],
    extensions=[],
    nested_types=[],
    enum_types=[],
    serialized_options=None,
    is_extendable=False,
    syntax='proto3',
    extension_ranges=[],
    oneofs=[],
    serialized_start=989,
    serialized_end=1071,
)

_UPDATETENSORBOARDRESPONSE = _descriptor.Descriptor(
    name='UpdateTensorboardResponse',
    full_name='grid.v1.UpdateTensorboardResponse',
    filename=None,
    file=DESCRIPTOR,
    containing_type=None,
    create_key=_descriptor._internal_create_key,
    fields=[
        _descriptor.FieldDescriptor(
            name='tensorboard',
            full_name='grid.v1.UpdateTensorboardResponse.tensorboard',
            index=0,
            number=1,
            type=11,
            cpp_type=10,
            label=1,
            has_default_value=False,
            default_value=None,
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            json_name='tensorboard',
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key
        ),
    ],
    extensions=[],
    nested_types=[],
    enum_types=[],
    serialized_options=None,
    is_extendable=False,
    syntax='proto3',
    extension_ranges=[],
    oneofs=[],
    serialized_start=1073,
    serialized_end=1156,
)

_UPDATETENSORBOARDSTATUSREQUEST = _descriptor.Descriptor(
    name='UpdateTensorboardStatusRequest',
    full_name='grid.v1.UpdateTensorboardStatusRequest',
    filename=None,
    file=DESCRIPTOR,
    containing_type=None,
    create_key=_descriptor._internal_create_key,
    fields=[
        _descriptor.FieldDescriptor(
            name='tensorboard',
            full_name='grid.v1.UpdateTensorboardStatusRequest.tensorboard',
            index=0,
            number=1,
            type=11,
            cpp_type=10,
            label=1,
            has_default_value=False,
            default_value=None,
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            json_name='tensorboard',
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key
        ),
    ],
    extensions=[],
    nested_types=[],
    enum_types=[],
    serialized_options=None,
    is_extendable=False,
    syntax='proto3',
    extension_ranges=[],
    oneofs=[],
    serialized_start=1158,
    serialized_end=1246,
)

_UPDATETENSORBOARDSTATUSRESPONSE = _descriptor.Descriptor(
    name='UpdateTensorboardStatusResponse',
    full_name='grid.v1.UpdateTensorboardStatusResponse',
    filename=None,
    file=DESCRIPTOR,
    containing_type=None,
    create_key=_descriptor._internal_create_key,
    fields=[
        _descriptor.FieldDescriptor(
            name='tensorboard',
            full_name='grid.v1.UpdateTensorboardStatusResponse.tensorboard',
            index=0,
            number=1,
            type=11,
            cpp_type=10,
            label=1,
            has_default_value=False,
            default_value=None,
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            json_name='tensorboard',
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key
        ),
    ],
    extensions=[],
    nested_types=[],
    enum_types=[],
    serialized_options=None,
    is_extendable=False,
    syntax='proto3',
    extension_ranges=[],
    oneofs=[],
    serialized_start=1248,
    serialized_end=1337,
)

_DELETETENSORBOARDREQUEST = _descriptor.Descriptor(
    name='DeleteTensorboardRequest',
    full_name='grid.v1.DeleteTensorboardRequest',
    filename=None,
    file=DESCRIPTOR,
    containing_type=None,
    create_key=_descriptor._internal_create_key,
    fields=[
        _descriptor.FieldDescriptor(
            name='tensorboard',
            full_name='grid.v1.DeleteTensorboardRequest.tensorboard',
            index=0,
            number=1,
            type=11,
            cpp_type=10,
            label=1,
            has_default_value=False,
            default_value=None,
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            json_name='tensorboard',
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key
        ),
    ],
    extensions=[],
    nested_types=[],
    enum_types=[],
    serialized_options=None,
    is_extendable=False,
    syntax='proto3',
    extension_ranges=[],
    oneofs=[],
    serialized_start=1339,
    serialized_end=1421,
)

_DELETETENSORBOARDRESPONSE = _descriptor.Descriptor(
    name='DeleteTensorboardResponse',
    full_name='grid.v1.DeleteTensorboardResponse',
    filename=None,
    file=DESCRIPTOR,
    containing_type=None,
    create_key=_descriptor._internal_create_key,
    fields=[
        _descriptor.FieldDescriptor(
            name='tensorboard',
            full_name='grid.v1.DeleteTensorboardResponse.tensorboard',
            index=0,
            number=1,
            type=11,
            cpp_type=10,
            label=1,
            has_default_value=False,
            default_value=None,
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            json_name='tensorboard',
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key
        ),
    ],
    extensions=[],
    nested_types=[],
    enum_types=[],
    serialized_options=None,
    is_extendable=False,
    syntax='proto3',
    extension_ranges=[],
    oneofs=[],
    serialized_start=1423,
    serialized_end=1506,
)

_WATCHTENSORBOARDSREQUEST = _descriptor.Descriptor(
    name='WatchTensorboardsRequest',
    full_name='grid.v1.WatchTensorboardsRequest',
    filename=None,
    file=DESCRIPTOR,
    containing_type=None,
    create_key=_descriptor._internal_create_key,
    fields=[
        _descriptor.FieldDescriptor(
            name='resource_version',
            full_name='grid.v1.WatchTensorboardsRequest.resource_version',
            index=0,
            number=1,
            type=9,
            cpp_type=9,
            label=1,
            has_default_value=False,
            default_value=b"".decode('utf-8'),
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            json_name='resourceVersion',
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key
        ),
        _descriptor.FieldDescriptor(
            name='limit',
            full_name='grid.v1.WatchTensorboardsRequest.limit',
            index=1,
            number=2,
            type=3,
            cpp_type=2,
            label=1,
            has_default_value=False,
            default_value=0,
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            json_name='limit',
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key
        ),
        _descriptor.FieldDescriptor(
            name='user_id',
            full_name='grid.v1.WatchTensorboardsRequest.user_id',
            index=2,
            number=4,
            type=9,
            cpp_type=9,
            label=1,
            has_default_value=False,
            default_value=b"".decode('utf-8'),
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            json_name='userId',
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key
        ),
        _descriptor.FieldDescriptor(
            name='cluster_id',
            full_name='grid.v1.WatchTensorboardsRequest.cluster_id',
            index=3,
            number=5,
            type=9,
            cpp_type=9,
            label=1,
            has_default_value=False,
            default_value=b"".decode('utf-8'),
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            json_name='clusterId',
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key
        ),
        _descriptor.FieldDescriptor(
            name='created_before',
            full_name='grid.v1.WatchTensorboardsRequest.created_before',
            index=4,
            number=6,
            type=11,
            cpp_type=10,
            label=1,
            has_default_value=False,
            default_value=None,
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            json_name='createdBefore',
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key
        ),
        _descriptor.FieldDescriptor(
            name='phase_in',
            full_name='grid.v1.WatchTensorboardsRequest.phase_in',
            index=5,
            number=7,
            type=14,
            cpp_type=8,
            label=3,
            has_default_value=False,
            default_value=[],
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            json_name='phaseIn',
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key
        ),
        _descriptor.FieldDescriptor(
            name='phase_not_in',
            full_name='grid.v1.WatchTensorboardsRequest.phase_not_in',
            index=6,
            number=8,
            type=14,
            cpp_type=8,
            label=3,
            has_default_value=False,
            default_value=[],
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            json_name='phaseNotIn',
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key
        ),
    ],
    extensions=[],
    nested_types=[],
    enum_types=[],
    serialized_options=None,
    is_extendable=False,
    syntax='proto3',
    extension_ranges=[],
    oneofs=[],
    serialized_start=1509,
    serialized_end=1838,
)

_WATCHTENSORBOARDSRESPONSE = _descriptor.Descriptor(
    name='WatchTensorboardsResponse',
    full_name='grid.v1.WatchTensorboardsResponse',
    filename=None,
    file=DESCRIPTOR,
    containing_type=None,
    create_key=_descriptor._internal_create_key,
    fields=[
        _descriptor.FieldDescriptor(
            name='resource_version',
            full_name='grid.v1.WatchTensorboardsResponse.resource_version',
            index=0,
            number=1,
            type=9,
            cpp_type=9,
            label=1,
            has_default_value=False,
            default_value=b"".decode('utf-8'),
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            json_name='resourceVersion',
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key
        ),
        _descriptor.FieldDescriptor(
            name='type',
            full_name='grid.v1.WatchTensorboardsResponse.type',
            index=1,
            number=2,
            type=14,
            cpp_type=8,
            label=1,
            has_default_value=False,
            default_value=0,
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            json_name='type',
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key
        ),
        _descriptor.FieldDescriptor(
            name='tensorboard',
            full_name='grid.v1.WatchTensorboardsResponse.tensorboard',
            index=2,
            number=3,
            type=11,
            cpp_type=10,
            label=1,
            has_default_value=False,
            default_value=None,
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            json_name='tensorboard',
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key
        ),
    ],
    extensions=[],
    nested_types=[],
    enum_types=[],
    serialized_options=None,
    is_extendable=False,
    syntax='proto3',
    extension_ranges=[],
    oneofs=[],
    serialized_start=1841,
    serialized_end=2012,
)

_CREATETENSORBOARDREQUEST.fields_by_name['tensorboard'].message_type = grid_dot_v1_dot_tensorboard__pb2._TENSORBOARD
_CREATETENSORBOARDRESPONSE.fields_by_name['tensorboard'].message_type = grid_dot_v1_dot_tensorboard__pb2._TENSORBOARD
_GETTENSORBOARDRESPONSE.fields_by_name['tensorboard'].message_type = grid_dot_v1_dot_tensorboard__pb2._TENSORBOARD
_LISTTENSORBOARDSREQUEST.fields_by_name['created_before'
                                        ].message_type = google_dot_protobuf_dot_timestamp__pb2._TIMESTAMP
_LISTTENSORBOARDSREQUEST.fields_by_name['phase_in'].enum_type = grid_dot_v1_dot_tensorboard__pb2._TENSORBOARDSTATE
_LISTTENSORBOARDSREQUEST.fields_by_name['phase_not_in'].enum_type = grid_dot_v1_dot_tensorboard__pb2._TENSORBOARDSTATE
_LISTTENSORBOARDSRESPONSE.fields_by_name['tensorboard'].message_type = grid_dot_v1_dot_tensorboard__pb2._TENSORBOARD
_UPDATETENSORBOARDREQUEST.fields_by_name['tensorboard'].message_type = grid_dot_v1_dot_tensorboard__pb2._TENSORBOARD
_UPDATETENSORBOARDRESPONSE.fields_by_name['tensorboard'].message_type = grid_dot_v1_dot_tensorboard__pb2._TENSORBOARD
_UPDATETENSORBOARDSTATUSREQUEST.fields_by_name['tensorboard'
                                               ].message_type = grid_dot_v1_dot_tensorboard__pb2._TENSORBOARD
_UPDATETENSORBOARDSTATUSRESPONSE.fields_by_name['tensorboard'
                                                ].message_type = grid_dot_v1_dot_tensorboard__pb2._TENSORBOARD
_DELETETENSORBOARDREQUEST.fields_by_name['tensorboard'].message_type = grid_dot_v1_dot_tensorboard__pb2._TENSORBOARD
_DELETETENSORBOARDRESPONSE.fields_by_name['tensorboard'].message_type = grid_dot_v1_dot_tensorboard__pb2._TENSORBOARD
_WATCHTENSORBOARDSREQUEST.fields_by_name['created_before'
                                         ].message_type = google_dot_protobuf_dot_timestamp__pb2._TIMESTAMP
_WATCHTENSORBOARDSREQUEST.fields_by_name['phase_in'].enum_type = grid_dot_v1_dot_tensorboard__pb2._TENSORBOARDSTATE
_WATCHTENSORBOARDSREQUEST.fields_by_name['phase_not_in'].enum_type = grid_dot_v1_dot_tensorboard__pb2._TENSORBOARDSTATE
_WATCHTENSORBOARDSRESPONSE.fields_by_name['type'].enum_type = grid_dot_v1_dot_metadata__pb2._WATCHEVENTTYPE
_WATCHTENSORBOARDSRESPONSE.fields_by_name['tensorboard'].message_type = grid_dot_v1_dot_tensorboard__pb2._TENSORBOARD
DESCRIPTOR.message_types_by_name['CreateTensorboardRequest'] = _CREATETENSORBOARDREQUEST
DESCRIPTOR.message_types_by_name['CreateTensorboardResponse'] = _CREATETENSORBOARDRESPONSE
DESCRIPTOR.message_types_by_name['GetTensorboardRequest'] = _GETTENSORBOARDREQUEST
DESCRIPTOR.message_types_by_name['GetTensorboardResponse'] = _GETTENSORBOARDRESPONSE
DESCRIPTOR.message_types_by_name['ListTensorboardsRequest'] = _LISTTENSORBOARDSREQUEST
DESCRIPTOR.message_types_by_name['ListTensorboardsResponse'] = _LISTTENSORBOARDSRESPONSE
DESCRIPTOR.message_types_by_name['UpdateTensorboardRequest'] = _UPDATETENSORBOARDREQUEST
DESCRIPTOR.message_types_by_name['UpdateTensorboardResponse'] = _UPDATETENSORBOARDRESPONSE
DESCRIPTOR.message_types_by_name['UpdateTensorboardStatusRequest'] = _UPDATETENSORBOARDSTATUSREQUEST
DESCRIPTOR.message_types_by_name['UpdateTensorboardStatusResponse'] = _UPDATETENSORBOARDSTATUSRESPONSE
DESCRIPTOR.message_types_by_name['DeleteTensorboardRequest'] = _DELETETENSORBOARDREQUEST
DESCRIPTOR.message_types_by_name['DeleteTensorboardResponse'] = _DELETETENSORBOARDRESPONSE
DESCRIPTOR.message_types_by_name['WatchTensorboardsRequest'] = _WATCHTENSORBOARDSREQUEST
DESCRIPTOR.message_types_by_name['WatchTensorboardsResponse'] = _WATCHTENSORBOARDSRESPONSE
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

CreateTensorboardRequest = _reflection.GeneratedProtocolMessageType(
    'CreateTensorboardRequest',
    (_message.Message, ),
    {
        'DESCRIPTOR': _CREATETENSORBOARDREQUEST,
        '__module__': 'grid.v1.tensorboard_service_pb2'
        # @@protoc_insertion_point(class_scope:grid.v1.CreateTensorboardRequest)
    }
)
_sym_db.RegisterMessage(CreateTensorboardRequest)

CreateTensorboardResponse = _reflection.GeneratedProtocolMessageType(
    'CreateTensorboardResponse',
    (_message.Message, ),
    {
        'DESCRIPTOR': _CREATETENSORBOARDRESPONSE,
        '__module__': 'grid.v1.tensorboard_service_pb2'
        # @@protoc_insertion_point(class_scope:grid.v1.CreateTensorboardResponse)
    }
)
_sym_db.RegisterMessage(CreateTensorboardResponse)

GetTensorboardRequest = _reflection.GeneratedProtocolMessageType(
    'GetTensorboardRequest',
    (_message.Message, ),
    {
        'DESCRIPTOR': _GETTENSORBOARDREQUEST,
        '__module__': 'grid.v1.tensorboard_service_pb2'
        # @@protoc_insertion_point(class_scope:grid.v1.GetTensorboardRequest)
    }
)
_sym_db.RegisterMessage(GetTensorboardRequest)

GetTensorboardResponse = _reflection.GeneratedProtocolMessageType(
    'GetTensorboardResponse',
    (_message.Message, ),
    {
        'DESCRIPTOR': _GETTENSORBOARDRESPONSE,
        '__module__': 'grid.v1.tensorboard_service_pb2'
        # @@protoc_insertion_point(class_scope:grid.v1.GetTensorboardResponse)
    }
)
_sym_db.RegisterMessage(GetTensorboardResponse)

ListTensorboardsRequest = _reflection.GeneratedProtocolMessageType(
    'ListTensorboardsRequest',
    (_message.Message, ),
    {
        'DESCRIPTOR': _LISTTENSORBOARDSREQUEST,
        '__module__': 'grid.v1.tensorboard_service_pb2'
        # @@protoc_insertion_point(class_scope:grid.v1.ListTensorboardsRequest)
    }
)
_sym_db.RegisterMessage(ListTensorboardsRequest)

ListTensorboardsResponse = _reflection.GeneratedProtocolMessageType(
    'ListTensorboardsResponse',
    (_message.Message, ),
    {
        'DESCRIPTOR': _LISTTENSORBOARDSRESPONSE,
        '__module__': 'grid.v1.tensorboard_service_pb2'
        # @@protoc_insertion_point(class_scope:grid.v1.ListTensorboardsResponse)
    }
)
_sym_db.RegisterMessage(ListTensorboardsResponse)

UpdateTensorboardRequest = _reflection.GeneratedProtocolMessageType(
    'UpdateTensorboardRequest',
    (_message.Message, ),
    {
        'DESCRIPTOR': _UPDATETENSORBOARDREQUEST,
        '__module__': 'grid.v1.tensorboard_service_pb2'
        # @@protoc_insertion_point(class_scope:grid.v1.UpdateTensorboardRequest)
    }
)
_sym_db.RegisterMessage(UpdateTensorboardRequest)

UpdateTensorboardResponse = _reflection.GeneratedProtocolMessageType(
    'UpdateTensorboardResponse',
    (_message.Message, ),
    {
        'DESCRIPTOR': _UPDATETENSORBOARDRESPONSE,
        '__module__': 'grid.v1.tensorboard_service_pb2'
        # @@protoc_insertion_point(class_scope:grid.v1.UpdateTensorboardResponse)
    }
)
_sym_db.RegisterMessage(UpdateTensorboardResponse)

UpdateTensorboardStatusRequest = _reflection.GeneratedProtocolMessageType(
    'UpdateTensorboardStatusRequest',
    (_message.Message, ),
    {
        'DESCRIPTOR': _UPDATETENSORBOARDSTATUSREQUEST,
        '__module__': 'grid.v1.tensorboard_service_pb2'
        # @@protoc_insertion_point(class_scope:grid.v1.UpdateTensorboardStatusRequest)
    }
)
_sym_db.RegisterMessage(UpdateTensorboardStatusRequest)

UpdateTensorboardStatusResponse = _reflection.GeneratedProtocolMessageType(
    'UpdateTensorboardStatusResponse',
    (_message.Message, ),
    {
        'DESCRIPTOR': _UPDATETENSORBOARDSTATUSRESPONSE,
        '__module__': 'grid.v1.tensorboard_service_pb2'
        # @@protoc_insertion_point(class_scope:grid.v1.UpdateTensorboardStatusResponse)
    }
)
_sym_db.RegisterMessage(UpdateTensorboardStatusResponse)

DeleteTensorboardRequest = _reflection.GeneratedProtocolMessageType(
    'DeleteTensorboardRequest',
    (_message.Message, ),
    {
        'DESCRIPTOR': _DELETETENSORBOARDREQUEST,
        '__module__': 'grid.v1.tensorboard_service_pb2'
        # @@protoc_insertion_point(class_scope:grid.v1.DeleteTensorboardRequest)
    }
)
_sym_db.RegisterMessage(DeleteTensorboardRequest)

DeleteTensorboardResponse = _reflection.GeneratedProtocolMessageType(
    'DeleteTensorboardResponse',
    (_message.Message, ),
    {
        'DESCRIPTOR': _DELETETENSORBOARDRESPONSE,
        '__module__': 'grid.v1.tensorboard_service_pb2'
        # @@protoc_insertion_point(class_scope:grid.v1.DeleteTensorboardResponse)
    }
)
_sym_db.RegisterMessage(DeleteTensorboardResponse)

WatchTensorboardsRequest = _reflection.GeneratedProtocolMessageType(
    'WatchTensorboardsRequest',
    (_message.Message, ),
    {
        'DESCRIPTOR': _WATCHTENSORBOARDSREQUEST,
        '__module__': 'grid.v1.tensorboard_service_pb2'
        # @@protoc_insertion_point(class_scope:grid.v1.WatchTensorboardsRequest)
    }
)
_sym_db.RegisterMessage(WatchTensorboardsRequest)

WatchTensorboardsResponse = _reflection.GeneratedProtocolMessageType(
    'WatchTensorboardsResponse',
    (_message.Message, ),
    {
        'DESCRIPTOR': _WATCHTENSORBOARDSRESPONSE,
        '__module__': 'grid.v1.tensorboard_service_pb2'
        # @@protoc_insertion_point(class_scope:grid.v1.WatchTensorboardsResponse)
    }
)
_sym_db.RegisterMessage(WatchTensorboardsResponse)

DESCRIPTOR._options = None

_TENSORBOARDSERVICE = _descriptor.ServiceDescriptor(
    name='TensorboardService',
    full_name='grid.v1.TensorboardService',
    file=DESCRIPTOR,
    index=0,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
    serialized_start=2015,
    serialized_end=2907,
    methods=[
        _descriptor.MethodDescriptor(
            name='CreateTensorboard',
            full_name='grid.v1.TensorboardService.CreateTensorboard',
            index=0,
            containing_service=None,
            input_type=_CREATETENSORBOARDREQUEST,
            output_type=_CREATETENSORBOARDRESPONSE,
            serialized_options=b'\202\323\344\223\002\032\"\025/v1/core/tensorboards:\001*',
            create_key=_descriptor._internal_create_key,
        ),
        _descriptor.MethodDescriptor(
            name='GetTensorboard',
            full_name='grid.v1.TensorboardService.GetTensorboard',
            index=1,
            containing_service=None,
            input_type=_GETTENSORBOARDREQUEST,
            output_type=_GETTENSORBOARDRESPONSE,
            serialized_options=b'\202\323\344\223\002\034\022\032/v1/core/tensorboards/{id}',
            create_key=_descriptor._internal_create_key,
        ),
        _descriptor.MethodDescriptor(
            name='ListTensorboards',
            full_name='grid.v1.TensorboardService.ListTensorboards',
            index=2,
            containing_service=None,
            input_type=_LISTTENSORBOARDSREQUEST,
            output_type=_LISTTENSORBOARDSRESPONSE,
            serialized_options=b'\202\323\344\223\002\027\022\025/v1/core/tensorboards',
            create_key=_descriptor._internal_create_key,
        ),
        _descriptor.MethodDescriptor(
            name='UpdateTensorboard',
            full_name='grid.v1.TensorboardService.UpdateTensorboard',
            index=3,
            containing_service=None,
            input_type=_UPDATETENSORBOARDREQUEST,
            output_type=_UPDATETENSORBOARDRESPONSE,
            serialized_options=b'\202\323\344\223\0024\032//v1/core/tensorboards/{tensorboard.metadata.id}:\001*',
            create_key=_descriptor._internal_create_key,
        ),
        _descriptor.MethodDescriptor(
            name='UpdateTensorboardStatus',
            full_name='grid.v1.TensorboardService.UpdateTensorboardStatus',
            index=4,
            containing_service=None,
            input_type=_UPDATETENSORBOARDSTATUSREQUEST,
            output_type=_UPDATETENSORBOARDSTATUSRESPONSE,
            serialized_options=None,
            create_key=_descriptor._internal_create_key,
        ),
        _descriptor.MethodDescriptor(
            name='DeleteTensorboard',
            full_name='grid.v1.TensorboardService.DeleteTensorboard',
            index=5,
            containing_service=None,
            input_type=_DELETETENSORBOARDREQUEST,
            output_type=_DELETETENSORBOARDRESPONSE,
            serialized_options=b'\202\323\344\223\0021*//v1/core/tensorboards/{tensorboard.metadata.id}',
            create_key=_descriptor._internal_create_key,
        ),
        _descriptor.MethodDescriptor(
            name='WatchTensorboards',
            full_name='grid.v1.TensorboardService.WatchTensorboards',
            index=6,
            containing_service=None,
            input_type=_WATCHTENSORBOARDSREQUEST,
            output_type=_WATCHTENSORBOARDSRESPONSE,
            serialized_options=None,
            create_key=_descriptor._internal_create_key,
        ),
    ]
)
_sym_db.RegisterServiceDescriptor(_TENSORBOARDSERVICE)

DESCRIPTOR.services_by_name['TensorboardService'] = _TENSORBOARDSERVICE

# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: grid/v1/integrations.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import enum_type_wrapper

# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()

DESCRIPTOR = _descriptor.FileDescriptor(
    name='grid/v1/integrations.proto',
    package='grid.v1',
    syntax='proto3',
    serialized_options=b'Z0github.com/gridai/grid/grid-backend/apis/grid/v1',
    create_key=_descriptor._internal_create_key,
    serialized_pb=
    b'\n\x1agrid/v1/integrations.proto\x12\x07grid.v1\"g\n\x05Token\x12\x14\n\x05token\x18\x01 \x01(\tR\x05token\x12\x32\n\x08provider\x18\x02 \x01(\x0e\x32\x16.grid.v1.TokenProviderR\x08provider\x12\x14\n\x05scope\x18\x03 \x01(\tR\x05scope\"0\n\x15GetGitHubTokenRequest\x12\x17\n\x07user_id\x18\x01 \x01(\tR\x06userId\">\n\x16GetGitHubTokenResponse\x12$\n\x05token\x18\x01 \x01(\x0b\x32\x0e.grid.v1.TokenR\x05token*J\n\rTokenProvider\x12\x1e\n\x1aTOKEN_PROVIDER_UNSPECIFIED\x10\x00\x12\x19\n\x15TOKEN_PROVIDER_GITHUB\x10\x01\x32g\n\x12IntegrationService\x12Q\n\x0eGetGitHubToken\x12\x1e.grid.v1.GetGitHubTokenRequest\x1a\x1f.grid.v1.GetGitHubTokenResponseB2Z0github.com/gridai/grid/grid-backend/apis/grid/v1b\x06proto3'
)

_TOKENPROVIDER = _descriptor.EnumDescriptor(
    name='TokenProvider',
    full_name='grid.v1.TokenProvider',
    filename=None,
    file=DESCRIPTOR,
    create_key=_descriptor._internal_create_key,
    values=[
        _descriptor.EnumValueDescriptor(
            name='TOKEN_PROVIDER_UNSPECIFIED',
            index=0,
            number=0,
            serialized_options=None,
            type=None,
            create_key=_descriptor._internal_create_key
        ),
        _descriptor.EnumValueDescriptor(
            name='TOKEN_PROVIDER_GITHUB',
            index=1,
            number=1,
            serialized_options=None,
            type=None,
            create_key=_descriptor._internal_create_key
        ),
    ],
    containing_type=None,
    serialized_options=None,
    serialized_start=258,
    serialized_end=332,
)
_sym_db.RegisterEnumDescriptor(_TOKENPROVIDER)

TokenProvider = enum_type_wrapper.EnumTypeWrapper(_TOKENPROVIDER)
TOKEN_PROVIDER_UNSPECIFIED = 0
TOKEN_PROVIDER_GITHUB = 1

_TOKEN = _descriptor.Descriptor(
    name='Token',
    full_name='grid.v1.Token',
    filename=None,
    file=DESCRIPTOR,
    containing_type=None,
    create_key=_descriptor._internal_create_key,
    fields=[
        _descriptor.FieldDescriptor(
            name='token',
            full_name='grid.v1.Token.token',
            index=0,
            number=1,
            type=9,
            cpp_type=9,
            label=1,
            has_default_value=False,
            default_value=b"".decode('utf-8'),
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            json_name='token',
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key
        ),
        _descriptor.FieldDescriptor(
            name='provider',
            full_name='grid.v1.Token.provider',
            index=1,
            number=2,
            type=14,
            cpp_type=8,
            label=1,
            has_default_value=False,
            default_value=0,
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            json_name='provider',
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key
        ),
        _descriptor.FieldDescriptor(
            name='scope',
            full_name='grid.v1.Token.scope',
            index=2,
            number=3,
            type=9,
            cpp_type=9,
            label=1,
            has_default_value=False,
            default_value=b"".decode('utf-8'),
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            json_name='scope',
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key
        ),
    ],
    extensions=[],
    nested_types=[],
    enum_types=[],
    serialized_options=None,
    is_extendable=False,
    syntax='proto3',
    extension_ranges=[],
    oneofs=[],
    serialized_start=39,
    serialized_end=142,
)

_GETGITHUBTOKENREQUEST = _descriptor.Descriptor(
    name='GetGitHubTokenRequest',
    full_name='grid.v1.GetGitHubTokenRequest',
    filename=None,
    file=DESCRIPTOR,
    containing_type=None,
    create_key=_descriptor._internal_create_key,
    fields=[
        _descriptor.FieldDescriptor(
            name='user_id',
            full_name='grid.v1.GetGitHubTokenRequest.user_id',
            index=0,
            number=1,
            type=9,
            cpp_type=9,
            label=1,
            has_default_value=False,
            default_value=b"".decode('utf-8'),
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            json_name='userId',
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key
        ),
    ],
    extensions=[],
    nested_types=[],
    enum_types=[],
    serialized_options=None,
    is_extendable=False,
    syntax='proto3',
    extension_ranges=[],
    oneofs=[],
    serialized_start=144,
    serialized_end=192,
)

_GETGITHUBTOKENRESPONSE = _descriptor.Descriptor(
    name='GetGitHubTokenResponse',
    full_name='grid.v1.GetGitHubTokenResponse',
    filename=None,
    file=DESCRIPTOR,
    containing_type=None,
    create_key=_descriptor._internal_create_key,
    fields=[
        _descriptor.FieldDescriptor(
            name='token',
            full_name='grid.v1.GetGitHubTokenResponse.token',
            index=0,
            number=1,
            type=11,
            cpp_type=10,
            label=1,
            has_default_value=False,
            default_value=None,
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            json_name='token',
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key
        ),
    ],
    extensions=[],
    nested_types=[],
    enum_types=[],
    serialized_options=None,
    is_extendable=False,
    syntax='proto3',
    extension_ranges=[],
    oneofs=[],
    serialized_start=194,
    serialized_end=256,
)

_TOKEN.fields_by_name['provider'].enum_type = _TOKENPROVIDER
_GETGITHUBTOKENRESPONSE.fields_by_name['token'].message_type = _TOKEN
DESCRIPTOR.message_types_by_name['Token'] = _TOKEN
DESCRIPTOR.message_types_by_name['GetGitHubTokenRequest'] = _GETGITHUBTOKENREQUEST
DESCRIPTOR.message_types_by_name['GetGitHubTokenResponse'] = _GETGITHUBTOKENRESPONSE
DESCRIPTOR.enum_types_by_name['TokenProvider'] = _TOKENPROVIDER
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

Token = _reflection.GeneratedProtocolMessageType(
    'Token',
    (_message.Message, ),
    {
        'DESCRIPTOR': _TOKEN,
        '__module__': 'grid.v1.integrations_pb2'
        # @@protoc_insertion_point(class_scope:grid.v1.Token)
    }
)
_sym_db.RegisterMessage(Token)

GetGitHubTokenRequest = _reflection.GeneratedProtocolMessageType(
    'GetGitHubTokenRequest',
    (_message.Message, ),
    {
        'DESCRIPTOR': _GETGITHUBTOKENREQUEST,
        '__module__': 'grid.v1.integrations_pb2'
        # @@protoc_insertion_point(class_scope:grid.v1.GetGitHubTokenRequest)
    }
)
_sym_db.RegisterMessage(GetGitHubTokenRequest)

GetGitHubTokenResponse = _reflection.GeneratedProtocolMessageType(
    'GetGitHubTokenResponse',
    (_message.Message, ),
    {
        'DESCRIPTOR': _GETGITHUBTOKENRESPONSE,
        '__module__': 'grid.v1.integrations_pb2'
        # @@protoc_insertion_point(class_scope:grid.v1.GetGitHubTokenResponse)
    }
)
_sym_db.RegisterMessage(GetGitHubTokenResponse)

DESCRIPTOR._options = None

_INTEGRATIONSERVICE = _descriptor.ServiceDescriptor(
    name='IntegrationService',
    full_name='grid.v1.IntegrationService',
    file=DESCRIPTOR,
    index=0,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
    serialized_start=334,
    serialized_end=437,
    methods=[
        _descriptor.MethodDescriptor(
            name='GetGitHubToken',
            full_name='grid.v1.IntegrationService.GetGitHubToken',
            index=0,
            containing_service=None,
            input_type=_GETGITHUBTOKENREQUEST,
            output_type=_GETGITHUBTOKENRESPONSE,
            serialized_options=None,
            create_key=_descriptor._internal_create_key,
        ),
    ]
)
_sym_db.RegisterServiceDescriptor(_INTEGRATIONSERVICE)

DESCRIPTOR.services_by_name['IntegrationService'] = _INTEGRATIONSERVICE

# @@protoc_insertion_point(module_scope)



"""TODO(rlizzo): THIS FILE IS PART OF PROJECT FEYNMAN
"""
from pathlib import Path
from typing import Set


def generate(src: Path) -> Set[str]:
    """
    Generates list of glob strings to ignore. These need to be parsed to identify
    which files are actually ignored.

    Returns
    -------
    Set[str]
        Glob strings to parse
    """
    # fallback files in case we can't find .gridignore
    fallback_ignore_files = {".dockerignore", ".gitignore"}

    # never include these paths in the package
    excluded_paths = {".git"}

    # if it is a file, then just read from it and return lines
    if src.is_file():
        return _read_and_filter(src)

    # ignores all paths from excluded paths by default
    ignore_globs = {f"{p}/" for p in excluded_paths}

    # look first for `.gridignore` files
    for path in src.glob('**/*'):
        if path.name in excluded_paths:
            continue
        if path.is_file():
            if path.name == ".gridignore":
                filtered = _read_and_filter(path)
                relative_dir = path.relative_to(src).parents[0]
                relative_globs = [str(relative_dir / glob) for glob in filtered]
                ignore_globs.update(relative_globs)

    # if found .gitignore, return it
    if len(ignore_globs) > len(excluded_paths):
        return ignore_globs

    # if not found, look everything else
    for path in src.glob('**/*'):
        if path.name in excluded_paths:
            continue
        if path.is_file():
            if path.name in fallback_ignore_files:
                filtered = _read_and_filter(path)
                relative_dir = path.relative_to(src).parents[0]
                relative_globs = [str(relative_dir / glob) for glob in filtered]
                ignore_globs.update(relative_globs)

    return ignore_globs


def _read_and_filter(path: Path) -> Set[str]:
    """Reads ignore file and filter comments."""
    raw_lines = [ln.strip() for ln in path.open().readlines()]
    return {ln for ln in raw_lines if not ln.startswith("#")}



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: grid/v1/image.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import enum_type_wrapper

# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()

from google.protobuf import any_pb2 as google_dot_protobuf_dot_any__pb2
from google.protobuf import timestamp_pb2 as google_dot_protobuf_dot_timestamp__pb2

from grid.protos.grid.v1 import metadata_pb2 as grid_dot_v1_dot_metadata__pb2

DESCRIPTOR = _descriptor.FileDescriptor(
    name='grid/v1/image.proto',
    package='grid.v1',
    syntax='proto3',
    serialized_options=b'Z0github.com/gridai/grid/grid-backend/apis/grid/v1',
    create_key=_descriptor._internal_create_key,
    serialized_pb=
    b'\n\x13grid/v1/image.proto\x12\x07grid.v1\x1a\x16grid/v1/metadata.proto\x1a\x1fgoogle/protobuf/timestamp.proto\x1a\x19google/protobuf/any.proto\"j\n\x12\x44\x65pendencyFileInfo\x12@\n\x0fpackage_manager\x18\x01 \x01(\x0e\x32\x17.grid.v1.PackageManagerR\x0epackageManager\x12\x12\n\x04path\x18\x02 \x01(\tR\x04path\"\xe0\x01\n\tImageSpec\x12\x16\n\x05image\x18\x01 \x01(\tH\x00R\x05image\x12 \n\ndockerfile\x18\x02 \x01(\tH\x00R\ndockerfile\x12\x35\n\x17on_image_build_commands\x18\x03 \x03(\tR\x14onImageBuildCommands\x12M\n\x14\x64\x65pendency_file_info\x18\x04 \x01(\x0b\x32\x1b.grid.v1.DependencyFileInfoR\x12\x64\x65pendencyFileInfoB\x13\n\x11\x62\x61se_image_source*e\n\x0ePackageManager\x12\x1f\n\x1bPACKAGE_MANAGER_UNSPECIFIED\x10\x00\x12\x17\n\x13PACKAGE_MANAGER_PIP\x10\x01\x12\x19\n\x15PACKAGE_MANAGER_CONDA\x10\x02\x42\x32Z0github.com/gridai/grid/grid-backend/apis/grid/v1b\x06proto3',
    dependencies=[
        grid_dot_v1_dot_metadata__pb2.DESCRIPTOR,
        google_dot_protobuf_dot_timestamp__pb2.DESCRIPTOR,
        google_dot_protobuf_dot_any__pb2.DESCRIPTOR,
    ]
)

_PACKAGEMANAGER = _descriptor.EnumDescriptor(
    name='PackageManager',
    full_name='grid.v1.PackageManager',
    filename=None,
    file=DESCRIPTOR,
    create_key=_descriptor._internal_create_key,
    values=[
        _descriptor.EnumValueDescriptor(
            name='PACKAGE_MANAGER_UNSPECIFIED',
            index=0,
            number=0,
            serialized_options=None,
            type=None,
            create_key=_descriptor._internal_create_key
        ),
        _descriptor.EnumValueDescriptor(
            name='PACKAGE_MANAGER_PIP',
            index=1,
            number=1,
            serialized_options=None,
            type=None,
            create_key=_descriptor._internal_create_key
        ),
        _descriptor.EnumValueDescriptor(
            name='PACKAGE_MANAGER_CONDA',
            index=2,
            number=2,
            serialized_options=None,
            type=None,
            create_key=_descriptor._internal_create_key
        ),
    ],
    containing_type=None,
    serialized_options=None,
    serialized_start=451,
    serialized_end=552,
)
_sym_db.RegisterEnumDescriptor(_PACKAGEMANAGER)

PackageManager = enum_type_wrapper.EnumTypeWrapper(_PACKAGEMANAGER)
PACKAGE_MANAGER_UNSPECIFIED = 0
PACKAGE_MANAGER_PIP = 1
PACKAGE_MANAGER_CONDA = 2

_DEPENDENCYFILEINFO = _descriptor.Descriptor(
    name='DependencyFileInfo',
    full_name='grid.v1.DependencyFileInfo',
    filename=None,
    file=DESCRIPTOR,
    containing_type=None,
    create_key=_descriptor._internal_create_key,
    fields=[
        _descriptor.FieldDescriptor(
            name='package_manager',
            full_name='grid.v1.DependencyFileInfo.package_manager',
            index=0,
            number=1,
            type=14,
            cpp_type=8,
            label=1,
            has_default_value=False,
            default_value=0,
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            json_name='packageManager',
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key
        ),
        _descriptor.FieldDescriptor(
            name='path',
            full_name='grid.v1.DependencyFileInfo.path',
            index=1,
            number=2,
            type=9,
            cpp_type=9,
            label=1,
            has_default_value=False,
            default_value=b"".decode('utf-8'),
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            json_name='path',
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key
        ),
    ],
    extensions=[],
    nested_types=[],
    enum_types=[],
    serialized_options=None,
    is_extendable=False,
    syntax='proto3',
    extension_ranges=[],
    oneofs=[],
    serialized_start=116,
    serialized_end=222,
)

_IMAGESPEC = _descriptor.Descriptor(
    name='ImageSpec',
    full_name='grid.v1.ImageSpec',
    filename=None,
    file=DESCRIPTOR,
    containing_type=None,
    create_key=_descriptor._internal_create_key,
    fields=[
        _descriptor.FieldDescriptor(
            name='image',
            full_name='grid.v1.ImageSpec.image',
            index=0,
            number=1,
            type=9,
            cpp_type=9,
            label=1,
            has_default_value=False,
            default_value=b"".decode('utf-8'),
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            json_name='image',
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key
        ),
        _descriptor.FieldDescriptor(
            name='dockerfile',
            full_name='grid.v1.ImageSpec.dockerfile',
            index=1,
            number=2,
            type=9,
            cpp_type=9,
            label=1,
            has_default_value=False,
            default_value=b"".decode('utf-8'),
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            json_name='dockerfile',
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key
        ),
        _descriptor.FieldDescriptor(
            name='on_image_build_commands',
            full_name='grid.v1.ImageSpec.on_image_build_commands',
            index=2,
            number=3,
            type=9,
            cpp_type=9,
            label=3,
            has_default_value=False,
            default_value=[],
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            json_name='onImageBuildCommands',
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key
        ),
        _descriptor.FieldDescriptor(
            name='dependency_file_info',
            full_name='grid.v1.ImageSpec.dependency_file_info',
            index=3,
            number=4,
            type=11,
            cpp_type=10,
            label=1,
            has_default_value=False,
            default_value=None,
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            json_name='dependencyFileInfo',
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key
        ),
    ],
    extensions=[],
    nested_types=[],
    enum_types=[],
    serialized_options=None,
    is_extendable=False,
    syntax='proto3',
    extension_ranges=[],
    oneofs=[
        _descriptor.OneofDescriptor(
            name='base_image_source',
            full_name='grid.v1.ImageSpec.base_image_source',
            index=0,
            containing_type=None,
            create_key=_descriptor._internal_create_key,
            fields=[]
        ),
    ],
    serialized_start=225,
    serialized_end=449,
)

_DEPENDENCYFILEINFO.fields_by_name['package_manager'].enum_type = _PACKAGEMANAGER
_IMAGESPEC.fields_by_name['dependency_file_info'].message_type = _DEPENDENCYFILEINFO
_IMAGESPEC.oneofs_by_name['base_image_source'].fields.append(_IMAGESPEC.fields_by_name['image'])
_IMAGESPEC.fields_by_name['image'].containing_oneof = _IMAGESPEC.oneofs_by_name['base_image_source']
_IMAGESPEC.oneofs_by_name['base_image_source'].fields.append(_IMAGESPEC.fields_by_name['dockerfile'])
_IMAGESPEC.fields_by_name['dockerfile'].containing_oneof = _IMAGESPEC.oneofs_by_name['base_image_source']
DESCRIPTOR.message_types_by_name['DependencyFileInfo'] = _DEPENDENCYFILEINFO
DESCRIPTOR.message_types_by_name['ImageSpec'] = _IMAGESPEC
DESCRIPTOR.enum_types_by_name['PackageManager'] = _PACKAGEMANAGER
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

DependencyFileInfo = _reflection.GeneratedProtocolMessageType(
    'DependencyFileInfo',
    (_message.Message, ),
    {
        'DESCRIPTOR': _DEPENDENCYFILEINFO,
        '__module__': 'grid.v1.image_pb2'
        # @@protoc_insertion_point(class_scope:grid.v1.DependencyFileInfo)
    }
)
_sym_db.RegisterMessage(DependencyFileInfo)

ImageSpec = _reflection.GeneratedProtocolMessageType(
    'ImageSpec',
    (_message.Message, ),
    {
        'DESCRIPTOR': _IMAGESPEC,
        '__module__': 'grid.v1.image_pb2'
        # @@protoc_insertion_point(class_scope:grid.v1.ImageSpec)
    }
)
_sym_db.RegisterMessage(ImageSpec)

DESCRIPTOR._options = None
# @@protoc_insertion_point(module_scope)



import asyncio

import click
from grpc.aio import AioRpcError

from grid.cli import rich_click
from grid.cli.client import Grid
from grid.protos.grid.v1.cluster_pb2 import Cluster
from grid.protos.grid.v1.cluster_service_pb2 import DeleteClusterRequest
from grid.protos.grid.v1.cluster_service_pb2_grpc import ClusterServiceStub
from grid.protos.grid.v1.metadata_pb2 import Metadata


@rich_click.group()
def delete() -> None:
    """Deletes a Run or Experiment."""
    pass


def doublecheck(item: str):
    warning_str = click.style('WARNING!', fg='red')
    message = f"""

    {warning_str}

    Your are about to delete the {item}.
    This will delete all the associated artifacts, logs, and metadata.

    Are you sure you want to do this?

   """
    click.confirm(message, abort=True)


@delete.command()
@rich_click.argument('experiment_ids', type=str, required=True, nargs=-1)
def experiment(experiment_ids: [str]):
    doublecheck(experiment_ids)
    client = Grid()
    for experiment in experiment_ids:
        client.delete(experiment_name=experiment)


@delete.command()
@rich_click.argument('run_ids', type=str, required=True, nargs=-1)
def run(run_ids: [str]):
    doublecheck(run_ids)
    client = Grid()
    for run in run_ids:
        client.delete(run_name=run)


@delete.command()
@rich_click.argument('cluster', type=str)
def cluster(cluster: str):
    """Delete cluster"""
    async def f():
        async with Grid.grpc_channel() as conn:
            await ClusterServiceStub(conn).DeleteCluster(
                DeleteClusterRequest(cluster=Cluster(metadata=Metadata(id=cluster, )))
            )

    try:
        asyncio.run(f())
    except AioRpcError as e:
        raise click.ClickException(f"cluster {cluster}: {e.details()}")



# Generated by the gRPC Python protocol compiler plugin. DO NOT EDIT!
import grpc

from grid.protos.grid.v1 import user_service_pb2 as grid_dot_v1_dot_user__service__pb2


class UserServiceStub(object):
    # missing associated documentation comment in .proto file
    pass

    def __init__(self, channel):
        """Constructor.

    Args:
      channel: A grpc.Channel.
    """
        self.CreateUser = channel.unary_unary(
            '/grid.v1.UserService/CreateUser',
            request_serializer=grid_dot_v1_dot_user__service__pb2.CreateUserRequest.SerializeToString,
            response_deserializer=grid_dot_v1_dot_user__service__pb2.CreateUserResponse.FromString,
        )
        self.GetUser = channel.unary_unary(
            '/grid.v1.UserService/GetUser',
            request_serializer=grid_dot_v1_dot_user__service__pb2.GetUserRequest.SerializeToString,
            response_deserializer=grid_dot_v1_dot_user__service__pb2.GetUserResponse.FromString,
        )
        self.ListUsers = channel.unary_unary(
            '/grid.v1.UserService/ListUsers',
            request_serializer=grid_dot_v1_dot_user__service__pb2.ListUsersRequest.SerializeToString,
            response_deserializer=grid_dot_v1_dot_user__service__pb2.ListUsersResponse.FromString,
        )
        self.UpdateUser = channel.unary_unary(
            '/grid.v1.UserService/UpdateUser',
            request_serializer=grid_dot_v1_dot_user__service__pb2.UpdateUserRequest.SerializeToString,
            response_deserializer=grid_dot_v1_dot_user__service__pb2.UpdateUserResponse.FromString,
        )
        self.UpdateUserStatus = channel.unary_unary(
            '/grid.v1.UserService/UpdateUserStatus',
            request_serializer=grid_dot_v1_dot_user__service__pb2.UpdateUserStatusRequest.SerializeToString,
            response_deserializer=grid_dot_v1_dot_user__service__pb2.UpdateUserStatusResponse.FromString,
        )
        self.DeleteUser = channel.unary_unary(
            '/grid.v1.UserService/DeleteUser',
            request_serializer=grid_dot_v1_dot_user__service__pb2.DeleteUserRequest.SerializeToString,
            response_deserializer=grid_dot_v1_dot_user__service__pb2.DeleteUserResponse.FromString,
        )
        self.WatchUsers = channel.unary_stream(
            '/grid.v1.UserService/WatchUsers',
            request_serializer=grid_dot_v1_dot_user__service__pb2.WatchUsersRequest.SerializeToString,
            response_deserializer=grid_dot_v1_dot_user__service__pb2.WatchUsersResponse.FromString,
        )
        self.StopUserWorkloads = channel.unary_unary(
            '/grid.v1.UserService/StopUserWorkloads',
            request_serializer=grid_dot_v1_dot_user__service__pb2.StopUserWorkloadsRequest.SerializeToString,
            response_deserializer=grid_dot_v1_dot_user__service__pb2.StopUserWorkloadsResponse.FromString,
        )


class UserServiceServicer(object):
    # missing associated documentation comment in .proto file
    pass

    def CreateUser(self, request, context):
        # missing associated documentation comment in .proto file
        pass
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def GetUser(self, request, context):
        # missing associated documentation comment in .proto file
        pass
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def ListUsers(self, request, context):
        # missing associated documentation comment in .proto file
        pass
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def UpdateUser(self, request, context):
        # missing associated documentation comment in .proto file
        pass
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def UpdateUserStatus(self, request, context):
        # missing associated documentation comment in .proto file
        pass
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def DeleteUser(self, request, context):
        # missing associated documentation comment in .proto file
        pass
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def WatchUsers(self, request, context):
        # missing associated documentation comment in .proto file
        pass
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def StopUserWorkloads(self, request, context):
        # missing associated documentation comment in .proto file
        pass
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')


def add_UserServiceServicer_to_server(servicer, server):
    rpc_method_handlers = {
        'CreateUser':
        grpc.unary_unary_rpc_method_handler(
            servicer.CreateUser,
            request_deserializer=grid_dot_v1_dot_user__service__pb2.CreateUserRequest.FromString,
            response_serializer=grid_dot_v1_dot_user__service__pb2.CreateUserResponse.SerializeToString,
        ),
        'GetUser':
        grpc.unary_unary_rpc_method_handler(
            servicer.GetUser,
            request_deserializer=grid_dot_v1_dot_user__service__pb2.GetUserRequest.FromString,
            response_serializer=grid_dot_v1_dot_user__service__pb2.GetUserResponse.SerializeToString,
        ),
        'ListUsers':
        grpc.unary_unary_rpc_method_handler(
            servicer.ListUsers,
            request_deserializer=grid_dot_v1_dot_user__service__pb2.ListUsersRequest.FromString,
            response_serializer=grid_dot_v1_dot_user__service__pb2.ListUsersResponse.SerializeToString,
        ),
        'UpdateUser':
        grpc.unary_unary_rpc_method_handler(
            servicer.UpdateUser,
            request_deserializer=grid_dot_v1_dot_user__service__pb2.UpdateUserRequest.FromString,
            response_serializer=grid_dot_v1_dot_user__service__pb2.UpdateUserResponse.SerializeToString,
        ),
        'UpdateUserStatus':
        grpc.unary_unary_rpc_method_handler(
            servicer.UpdateUserStatus,
            request_deserializer=grid_dot_v1_dot_user__service__pb2.UpdateUserStatusRequest.FromString,
            response_serializer=grid_dot_v1_dot_user__service__pb2.UpdateUserStatusResponse.SerializeToString,
        ),
        'DeleteUser':
        grpc.unary_unary_rpc_method_handler(
            servicer.DeleteUser,
            request_deserializer=grid_dot_v1_dot_user__service__pb2.DeleteUserRequest.FromString,
            response_serializer=grid_dot_v1_dot_user__service__pb2.DeleteUserResponse.SerializeToString,
        ),
        'WatchUsers':
        grpc.unary_stream_rpc_method_handler(
            servicer.WatchUsers,
            request_deserializer=grid_dot_v1_dot_user__service__pb2.WatchUsersRequest.FromString,
            response_serializer=grid_dot_v1_dot_user__service__pb2.WatchUsersResponse.SerializeToString,
        ),
        'StopUserWorkloads':
        grpc.unary_unary_rpc_method_handler(
            servicer.StopUserWorkloads,
            request_deserializer=grid_dot_v1_dot_user__service__pb2.StopUserWorkloadsRequest.FromString,
            response_serializer=grid_dot_v1_dot_user__service__pb2.StopUserWorkloadsResponse.SerializeToString,
        ),
    }
    generic_handler = grpc.method_handlers_generic_handler('grid.v1.UserService', rpc_method_handlers)
    server.add_generic_rpc_handlers((generic_handler, ))



# Generated by the gRPC Python protocol compiler plugin. DO NOT EDIT!
import grpc

from grid.protos.grid.v1 import datastore_service_pb2 as grid_dot_v1_dot_datastore__service__pb2


class DatastoreServiceStub(object):
    # missing associated documentation comment in .proto file
    pass

    def __init__(self, channel):
        """Constructor.

    Args:
      channel: A grpc.Channel.
    """
        self.CreateDatastore = channel.unary_unary(
            '/grid.v1.DatastoreService/CreateDatastore',
            request_serializer=grid_dot_v1_dot_datastore__service__pb2.CreateDatastoreRequest.SerializeToString,
            response_deserializer=grid_dot_v1_dot_datastore__service__pb2.CreateDatastoreResponse.FromString,
        )
        self.GetDatastore = channel.unary_unary(
            '/grid.v1.DatastoreService/GetDatastore',
            request_serializer=grid_dot_v1_dot_datastore__service__pb2.GetDatastoreRequest.SerializeToString,
            response_deserializer=grid_dot_v1_dot_datastore__service__pb2.GetDatastoreResponse.FromString,
        )
        self.ListDatastores = channel.unary_unary(
            '/grid.v1.DatastoreService/ListDatastores',
            request_serializer=grid_dot_v1_dot_datastore__service__pb2.ListDatastoresRequest.SerializeToString,
            response_deserializer=grid_dot_v1_dot_datastore__service__pb2.ListDatastoresResponse.FromString,
        )
        self.UpdateDatastore = channel.unary_unary(
            '/grid.v1.DatastoreService/UpdateDatastore',
            request_serializer=grid_dot_v1_dot_datastore__service__pb2.UpdateDatastoreRequest.SerializeToString,
            response_deserializer=grid_dot_v1_dot_datastore__service__pb2.UpdateDatastoreResponse.FromString,
        )
        self.UpdateDatastoreStatus = channel.unary_unary(
            '/grid.v1.DatastoreService/UpdateDatastoreStatus',
            request_serializer=grid_dot_v1_dot_datastore__service__pb2.UpdateDatastoreStatusRequest.SerializeToString,
            response_deserializer=grid_dot_v1_dot_datastore__service__pb2.UpdateDatastoreStatusResponse.FromString,
        )
        self.DeleteDatastore = channel.unary_unary(
            '/grid.v1.DatastoreService/DeleteDatastore',
            request_serializer=grid_dot_v1_dot_datastore__service__pb2.DeleteDatastoreRequest.SerializeToString,
            response_deserializer=grid_dot_v1_dot_datastore__service__pb2.DeleteDatastoreResponse.FromString,
        )
        self.WatchDatastores = channel.unary_stream(
            '/grid.v1.DatastoreService/WatchDatastores',
            request_serializer=grid_dot_v1_dot_datastore__service__pb2.WatchDatastoresRequest.SerializeToString,
            response_deserializer=grid_dot_v1_dot_datastore__service__pb2.WatchDatastoresResponse.FromString,
        )


class DatastoreServiceServicer(object):
    # missing associated documentation comment in .proto file
    pass

    def CreateDatastore(self, request, context):
        # missing associated documentation comment in .proto file
        pass
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def GetDatastore(self, request, context):
        # missing associated documentation comment in .proto file
        pass
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def ListDatastores(self, request, context):
        # missing associated documentation comment in .proto file
        pass
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def UpdateDatastore(self, request, context):
        # missing associated documentation comment in .proto file
        pass
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def UpdateDatastoreStatus(self, request, context):
        # missing associated documentation comment in .proto file
        pass
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def DeleteDatastore(self, request, context):
        # missing associated documentation comment in .proto file
        pass
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def WatchDatastores(self, request, context):
        # missing associated documentation comment in .proto file
        pass
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')


def add_DatastoreServiceServicer_to_server(servicer, server):
    rpc_method_handlers = {
        'CreateDatastore':
        grpc.unary_unary_rpc_method_handler(
            servicer.CreateDatastore,
            request_deserializer=grid_dot_v1_dot_datastore__service__pb2.CreateDatastoreRequest.FromString,
            response_serializer=grid_dot_v1_dot_datastore__service__pb2.CreateDatastoreResponse.SerializeToString,
        ),
        'GetDatastore':
        grpc.unary_unary_rpc_method_handler(
            servicer.GetDatastore,
            request_deserializer=grid_dot_v1_dot_datastore__service__pb2.GetDatastoreRequest.FromString,
            response_serializer=grid_dot_v1_dot_datastore__service__pb2.GetDatastoreResponse.SerializeToString,
        ),
        'ListDatastores':
        grpc.unary_unary_rpc_method_handler(
            servicer.ListDatastores,
            request_deserializer=grid_dot_v1_dot_datastore__service__pb2.ListDatastoresRequest.FromString,
            response_serializer=grid_dot_v1_dot_datastore__service__pb2.ListDatastoresResponse.SerializeToString,
        ),
        'UpdateDatastore':
        grpc.unary_unary_rpc_method_handler(
            servicer.UpdateDatastore,
            request_deserializer=grid_dot_v1_dot_datastore__service__pb2.UpdateDatastoreRequest.FromString,
            response_serializer=grid_dot_v1_dot_datastore__service__pb2.UpdateDatastoreResponse.SerializeToString,
        ),
        'UpdateDatastoreStatus':
        grpc.unary_unary_rpc_method_handler(
            servicer.UpdateDatastoreStatus,
            request_deserializer=grid_dot_v1_dot_datastore__service__pb2.UpdateDatastoreStatusRequest.FromString,
            response_serializer=grid_dot_v1_dot_datastore__service__pb2.UpdateDatastoreStatusResponse.SerializeToString,
        ),
        'DeleteDatastore':
        grpc.unary_unary_rpc_method_handler(
            servicer.DeleteDatastore,
            request_deserializer=grid_dot_v1_dot_datastore__service__pb2.DeleteDatastoreRequest.FromString,
            response_serializer=grid_dot_v1_dot_datastore__service__pb2.DeleteDatastoreResponse.SerializeToString,
        ),
        'WatchDatastores':
        grpc.unary_stream_rpc_method_handler(
            servicer.WatchDatastores,
            request_deserializer=grid_dot_v1_dot_datastore__service__pb2.WatchDatastoresRequest.FromString,
            response_serializer=grid_dot_v1_dot_datastore__service__pb2.WatchDatastoresResponse.SerializeToString,
        ),
    }
    generic_handler = grpc.method_handlers_generic_handler('grid.v1.DatastoreService', rpc_method_handlers)
    server.add_generic_rpc_handlers((generic_handler, ))



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: grid/v1/datastore_service.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database

# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()

from google.api import annotations_pb2 as google_dot_api_dot_annotations__pb2

from grid.protos.grid.v1 import datastore_pb2 as grid_dot_v1_dot_datastore__pb2
from grid.protos.grid.v1 import metadata_pb2 as grid_dot_v1_dot_metadata__pb2

DESCRIPTOR = _descriptor.FileDescriptor(
    name='grid/v1/datastore_service.proto',
    package='grid.v1',
    syntax='proto3',
    serialized_options=b'Z0github.com/gridai/grid/grid-backend/apis/grid/v1',
    create_key=_descriptor._internal_create_key,
    serialized_pb=
    b'\n\x1fgrid/v1/datastore_service.proto\x12\x07grid.v1\x1a\x1cgoogle/api/annotations.proto\x1a\x16grid/v1/metadata.proto\x1a\x17grid/v1/datastore.proto\"J\n\x16\x43reateDatastoreRequest\x12\x30\n\tdatastore\x18\x01 \x01(\x0b\x32\x12.grid.v1.DatastoreR\tdatastore\"K\n\x17\x43reateDatastoreResponse\x12\x30\n\tdatastore\x18\x01 \x01(\x0b\x32\x12.grid.v1.DatastoreR\tdatastore\"%\n\x13GetDatastoreRequest\x12\x0e\n\x02id\x18\x01 \x01(\tR\x02id\"H\n\x14GetDatastoreResponse\x12\x30\n\tdatastore\x18\x01 \x01(\x0b\x32\x12.grid.v1.DatastoreR\tdatastore\"\xd5\x01\n\x15ListDatastoresRequest\x12%\n\x0e\x63ontinue_token\x18\x01 \x01(\tR\rcontinueToken\x12)\n\x10resource_version\x18\x02 \x01(\tR\x0fresourceVersion\x12\x14\n\x05limit\x18\x03 \x01(\x03R\x05limit\x12\x17\n\x07user_id\x18\x04 \x01(\tR\x06userId\x12\x1c\n\tavailable\x18\x05 \x01(\x08R\tavailable\x12\x1d\n\ncluster_id\x18\x06 \x01(\tR\tclusterId\"\x9c\x01\n\x16ListDatastoresResponse\x12\x30\n\tdatastore\x18\x01 \x03(\x0b\x32\x12.grid.v1.DatastoreR\tdatastore\x12%\n\x0e\x63ontinue_token\x18\x02 \x01(\tR\rcontinueToken\x12)\n\x10resource_version\x18\x03 \x01(\tR\x0fresourceVersion\"J\n\x16UpdateDatastoreRequest\x12\x30\n\tdatastore\x18\x01 \x01(\x0b\x32\x12.grid.v1.DatastoreR\tdatastore\"K\n\x17UpdateDatastoreResponse\x12\x30\n\tdatastore\x18\x01 \x01(\x0b\x32\x12.grid.v1.DatastoreR\tdatastore\"P\n\x1cUpdateDatastoreStatusRequest\x12\x30\n\tdatastore\x18\x01 \x01(\x0b\x32\x12.grid.v1.DatastoreR\tdatastore\"Q\n\x1dUpdateDatastoreStatusResponse\x12\x30\n\tdatastore\x18\x01 \x01(\x0b\x32\x12.grid.v1.DatastoreR\tdatastore\"J\n\x16\x44\x65leteDatastoreRequest\x12\x30\n\tdatastore\x18\x01 \x01(\x0b\x32\x12.grid.v1.DatastoreR\tdatastore\"K\n\x17\x44\x65leteDatastoreResponse\x12\x30\n\tdatastore\x18\x01 \x01(\x0b\x32\x12.grid.v1.DatastoreR\tdatastore\"\xaf\x01\n\x16WatchDatastoresRequest\x12)\n\x10resource_version\x18\x01 \x01(\tR\x0fresourceVersion\x12\x14\n\x05limit\x18\x02 \x01(\x03R\x05limit\x12\x17\n\x07user_id\x18\x04 \x01(\tR\x06userId\x12\x1c\n\tavailable\x18\x05 \x01(\x08R\tavailable\x12\x1d\n\ncluster_id\x18\x06 \x01(\tR\tclusterId\"\xa3\x01\n\x17WatchDatastoresResponse\x12)\n\x10resource_version\x18\x01 \x01(\tR\x0fresourceVersion\x12+\n\x04type\x18\x02 \x01(\x0e\x32\x17.grid.v1.WatchEventTypeR\x04type\x12\x30\n\tdatastore\x18\x03 \x01(\x0b\x32\x12.grid.v1.DatastoreR\tdatastore2\xfe\x04\n\x10\x44\x61tastoreService\x12V\n\x0f\x43reateDatastore\x12\x1f.grid.v1.CreateDatastoreRequest\x1a .grid.v1.CreateDatastoreResponse\"\x00\x12M\n\x0cGetDatastore\x12\x1c.grid.v1.GetDatastoreRequest\x1a\x1d.grid.v1.GetDatastoreResponse\"\x00\x12S\n\x0eListDatastores\x12\x1e.grid.v1.ListDatastoresRequest\x1a\x1f.grid.v1.ListDatastoresResponse\"\x00\x12V\n\x0fUpdateDatastore\x12\x1f.grid.v1.UpdateDatastoreRequest\x1a .grid.v1.UpdateDatastoreResponse\"\x00\x12\x66\n\x15UpdateDatastoreStatus\x12%.grid.v1.UpdateDatastoreStatusRequest\x1a&.grid.v1.UpdateDatastoreStatusResponse\x12V\n\x0f\x44\x65leteDatastore\x12\x1f.grid.v1.DeleteDatastoreRequest\x1a .grid.v1.DeleteDatastoreResponse\"\x00\x12V\n\x0fWatchDatastores\x12\x1f.grid.v1.WatchDatastoresRequest\x1a .grid.v1.WatchDatastoresResponse0\x01\x42\x32Z0github.com/gridai/grid/grid-backend/apis/grid/v1b\x06proto3',
    dependencies=[
        google_dot_api_dot_annotations__pb2.DESCRIPTOR,
        grid_dot_v1_dot_metadata__pb2.DESCRIPTOR,
        grid_dot_v1_dot_datastore__pb2.DESCRIPTOR,
    ]
)

_CREATEDATASTOREREQUEST = _descriptor.Descriptor(
    name='CreateDatastoreRequest',
    full_name='grid.v1.CreateDatastoreRequest',
    filename=None,
    file=DESCRIPTOR,
    containing_type=None,
    create_key=_descriptor._internal_create_key,
    fields=[
        _descriptor.FieldDescriptor(
            name='datastore',
            full_name='grid.v1.CreateDatastoreRequest.datastore',
            index=0,
            number=1,
            type=11,
            cpp_type=10,
            label=1,
            has_default_value=False,
            default_value=None,
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            json_name='datastore',
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key
        ),
    ],
    extensions=[],
    nested_types=[],
    enum_types=[],
    serialized_options=None,
    is_extendable=False,
    syntax='proto3',
    extension_ranges=[],
    oneofs=[],
    serialized_start=123,
    serialized_end=197,
)

_CREATEDATASTORERESPONSE = _descriptor.Descriptor(
    name='CreateDatastoreResponse',
    full_name='grid.v1.CreateDatastoreResponse',
    filename=None,
    file=DESCRIPTOR,
    containing_type=None,
    create_key=_descriptor._internal_create_key,
    fields=[
        _descriptor.FieldDescriptor(
            name='datastore',
            full_name='grid.v1.CreateDatastoreResponse.datastore',
            index=0,
            number=1,
            type=11,
            cpp_type=10,
            label=1,
            has_default_value=False,
            default_value=None,
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            json_name='datastore',
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key
        ),
    ],
    extensions=[],
    nested_types=[],
    enum_types=[],
    serialized_options=None,
    is_extendable=False,
    syntax='proto3',
    extension_ranges=[],
    oneofs=[],
    serialized_start=199,
    serialized_end=274,
)

_GETDATASTOREREQUEST = _descriptor.Descriptor(
    name='GetDatastoreRequest',
    full_name='grid.v1.GetDatastoreRequest',
    filename=None,
    file=DESCRIPTOR,
    containing_type=None,
    create_key=_descriptor._internal_create_key,
    fields=[
        _descriptor.FieldDescriptor(
            name='id',
            full_name='grid.v1.GetDatastoreRequest.id',
            index=0,
            number=1,
            type=9,
            cpp_type=9,
            label=1,
            has_default_value=False,
            default_value=b"".decode('utf-8'),
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            json_name='id',
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key
        ),
    ],
    extensions=[],
    nested_types=[],
    enum_types=[],
    serialized_options=None,
    is_extendable=False,
    syntax='proto3',
    extension_ranges=[],
    oneofs=[],
    serialized_start=276,
    serialized_end=313,
)

_GETDATASTORERESPONSE = _descriptor.Descriptor(
    name='GetDatastoreResponse',
    full_name='grid.v1.GetDatastoreResponse',
    filename=None,
    file=DESCRIPTOR,
    containing_type=None,
    create_key=_descriptor._internal_create_key,
    fields=[
        _descriptor.FieldDescriptor(
            name='datastore',
            full_name='grid.v1.GetDatastoreResponse.datastore',
            index=0,
            number=1,
            type=11,
            cpp_type=10,
            label=1,
            has_default_value=False,
            default_value=None,
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            json_name='datastore',
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key
        ),
    ],
    extensions=[],
    nested_types=[],
    enum_types=[],
    serialized_options=None,
    is_extendable=False,
    syntax='proto3',
    extension_ranges=[],
    oneofs=[],
    serialized_start=315,
    serialized_end=387,
)

_LISTDATASTORESREQUEST = _descriptor.Descriptor(
    name='ListDatastoresRequest',
    full_name='grid.v1.ListDatastoresRequest',
    filename=None,
    file=DESCRIPTOR,
    containing_type=None,
    create_key=_descriptor._internal_create_key,
    fields=[
        _descriptor.FieldDescriptor(
            name='continue_token',
            full_name='grid.v1.ListDatastoresRequest.continue_token',
            index=0,
            number=1,
            type=9,
            cpp_type=9,
            label=1,
            has_default_value=False,
            default_value=b"".decode('utf-8'),
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            json_name='continueToken',
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key
        ),
        _descriptor.FieldDescriptor(
            name='resource_version',
            full_name='grid.v1.ListDatastoresRequest.resource_version',
            index=1,
            number=2,
            type=9,
            cpp_type=9,
            label=1,
            has_default_value=False,
            default_value=b"".decode('utf-8'),
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            json_name='resourceVersion',
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key
        ),
        _descriptor.FieldDescriptor(
            name='limit',
            full_name='grid.v1.ListDatastoresRequest.limit',
            index=2,
            number=3,
            type=3,
            cpp_type=2,
            label=1,
            has_default_value=False,
            default_value=0,
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            json_name='limit',
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key
        ),
        _descriptor.FieldDescriptor(
            name='user_id',
            full_name='grid.v1.ListDatastoresRequest.user_id',
            index=3,
            number=4,
            type=9,
            cpp_type=9,
            label=1,
            has_default_value=False,
            default_value=b"".decode('utf-8'),
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            json_name='userId',
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key
        ),
        _descriptor.FieldDescriptor(
            name='available',
            full_name='grid.v1.ListDatastoresRequest.available',
            index=4,
            number=5,
            type=8,
            cpp_type=7,
            label=1,
            has_default_value=False,
            default_value=False,
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            json_name='available',
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key
        ),
        _descriptor.FieldDescriptor(
            name='cluster_id',
            full_name='grid.v1.ListDatastoresRequest.cluster_id',
            index=5,
            number=6,
            type=9,
            cpp_type=9,
            label=1,
            has_default_value=False,
            default_value=b"".decode('utf-8'),
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            json_name='clusterId',
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key
        ),
    ],
    extensions=[],
    nested_types=[],
    enum_types=[],
    serialized_options=None,
    is_extendable=False,
    syntax='proto3',
    extension_ranges=[],
    oneofs=[],
    serialized_start=390,
    serialized_end=603,
)

_LISTDATASTORESRESPONSE = _descriptor.Descriptor(
    name='ListDatastoresResponse',
    full_name='grid.v1.ListDatastoresResponse',
    filename=None,
    file=DESCRIPTOR,
    containing_type=None,
    create_key=_descriptor._internal_create_key,
    fields=[
        _descriptor.FieldDescriptor(
            name='datastore',
            full_name='grid.v1.ListDatastoresResponse.datastore',
            index=0,
            number=1,
            type=11,
            cpp_type=10,
            label=3,
            has_default_value=False,
            default_value=[],
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            json_name='datastore',
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key
        ),
        _descriptor.FieldDescriptor(
            name='continue_token',
            full_name='grid.v1.ListDatastoresResponse.continue_token',
            index=1,
            number=2,
            type=9,
            cpp_type=9,
            label=1,
            has_default_value=False,
            default_value=b"".decode('utf-8'),
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            json_name='continueToken',
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key
        ),
        _descriptor.FieldDescriptor(
            name='resource_version',
            full_name='grid.v1.ListDatastoresResponse.resource_version',
            index=2,
            number=3,
            type=9,
            cpp_type=9,
            label=1,
            has_default_value=False,
            default_value=b"".decode('utf-8'),
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            json_name='resourceVersion',
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key
        ),
    ],
    extensions=[],
    nested_types=[],
    enum_types=[],
    serialized_options=None,
    is_extendable=False,
    syntax='proto3',
    extension_ranges=[],
    oneofs=[],
    serialized_start=606,
    serialized_end=762,
)

_UPDATEDATASTOREREQUEST = _descriptor.Descriptor(
    name='UpdateDatastoreRequest',
    full_name='grid.v1.UpdateDatastoreRequest',
    filename=None,
    file=DESCRIPTOR,
    containing_type=None,
    create_key=_descriptor._internal_create_key,
    fields=[
        _descriptor.FieldDescriptor(
            name='datastore',
            full_name='grid.v1.UpdateDatastoreRequest.datastore',
            index=0,
            number=1,
            type=11,
            cpp_type=10,
            label=1,
            has_default_value=False,
            default_value=None,
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            json_name='datastore',
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key
        ),
    ],
    extensions=[],
    nested_types=[],
    enum_types=[],
    serialized_options=None,
    is_extendable=False,
    syntax='proto3',
    extension_ranges=[],
    oneofs=[],
    serialized_start=764,
    serialized_end=838,
)

_UPDATEDATASTORERESPONSE = _descriptor.Descriptor(
    name='UpdateDatastoreResponse',
    full_name='grid.v1.UpdateDatastoreResponse',
    filename=None,
    file=DESCRIPTOR,
    containing_type=None,
    create_key=_descriptor._internal_create_key,
    fields=[
        _descriptor.FieldDescriptor(
            name='datastore',
            full_name='grid.v1.UpdateDatastoreResponse.datastore',
            index=0,
            number=1,
            type=11,
            cpp_type=10,
            label=1,
            has_default_value=False,
            default_value=None,
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            json_name='datastore',
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key
        ),
    ],
    extensions=[],
    nested_types=[],
    enum_types=[],
    serialized_options=None,
    is_extendable=False,
    syntax='proto3',
    extension_ranges=[],
    oneofs=[],
    serialized_start=840,
    serialized_end=915,
)

_UPDATEDATASTORESTATUSREQUEST = _descriptor.Descriptor(
    name='UpdateDatastoreStatusRequest',
    full_name='grid.v1.UpdateDatastoreStatusRequest',
    filename=None,
    file=DESCRIPTOR,
    containing_type=None,
    create_key=_descriptor._internal_create_key,
    fields=[
        _descriptor.FieldDescriptor(
            name='datastore',
            full_name='grid.v1.UpdateDatastoreStatusRequest.datastore',
            index=0,
            number=1,
            type=11,
            cpp_type=10,
            label=1,
            has_default_value=False,
            default_value=None,
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            json_name='datastore',
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key
        ),
    ],
    extensions=[],
    nested_types=[],
    enum_types=[],
    serialized_options=None,
    is_extendable=False,
    syntax='proto3',
    extension_ranges=[],
    oneofs=[],
    serialized_start=917,
    serialized_end=997,
)

_UPDATEDATASTORESTATUSRESPONSE = _descriptor.Descriptor(
    name='UpdateDatastoreStatusResponse',
    full_name='grid.v1.UpdateDatastoreStatusResponse',
    filename=None,
    file=DESCRIPTOR,
    containing_type=None,
    create_key=_descriptor._internal_create_key,
    fields=[
        _descriptor.FieldDescriptor(
            name='datastore',
            full_name='grid.v1.UpdateDatastoreStatusResponse.datastore',
            index=0,
            number=1,
            type=11,
            cpp_type=10,
            label=1,
            has_default_value=False,
            default_value=None,
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            json_name='datastore',
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key
        ),
    ],
    extensions=[],
    nested_types=[],
    enum_types=[],
    serialized_options=None,
    is_extendable=False,
    syntax='proto3',
    extension_ranges=[],
    oneofs=[],
    serialized_start=999,
    serialized_end=1080,
)

_DELETEDATASTOREREQUEST = _descriptor.Descriptor(
    name='DeleteDatastoreRequest',
    full_name='grid.v1.DeleteDatastoreRequest',
    filename=None,
    file=DESCRIPTOR,
    containing_type=None,
    create_key=_descriptor._internal_create_key,
    fields=[
        _descriptor.FieldDescriptor(
            name='datastore',
            full_name='grid.v1.DeleteDatastoreRequest.datastore',
            index=0,
            number=1,
            type=11,
            cpp_type=10,
            label=1,
            has_default_value=False,
            default_value=None,
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            json_name='datastore',
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key
        ),
    ],
    extensions=[],
    nested_types=[],
    enum_types=[],
    serialized_options=None,
    is_extendable=False,
    syntax='proto3',
    extension_ranges=[],
    oneofs=[],
    serialized_start=1082,
    serialized_end=1156,
)

_DELETEDATASTORERESPONSE = _descriptor.Descriptor(
    name='DeleteDatastoreResponse',
    full_name='grid.v1.DeleteDatastoreResponse',
    filename=None,
    file=DESCRIPTOR,
    containing_type=None,
    create_key=_descriptor._internal_create_key,
    fields=[
        _descriptor.FieldDescriptor(
            name='datastore',
            full_name='grid.v1.DeleteDatastoreResponse.datastore',
            index=0,
            number=1,
            type=11,
            cpp_type=10,
            label=1,
            has_default_value=False,
            default_value=None,
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            json_name='datastore',
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key
        ),
    ],
    extensions=[],
    nested_types=[],
    enum_types=[],
    serialized_options=None,
    is_extendable=False,
    syntax='proto3',
    extension_ranges=[],
    oneofs=[],
    serialized_start=1158,
    serialized_end=1233,
)

_WATCHDATASTORESREQUEST = _descriptor.Descriptor(
    name='WatchDatastoresRequest',
    full_name='grid.v1.WatchDatastoresRequest',
    filename=None,
    file=DESCRIPTOR,
    containing_type=None,
    create_key=_descriptor._internal_create_key,
    fields=[
        _descriptor.FieldDescriptor(
            name='resource_version',
            full_name='grid.v1.WatchDatastoresRequest.resource_version',
            index=0,
            number=1,
            type=9,
            cpp_type=9,
            label=1,
            has_default_value=False,
            default_value=b"".decode('utf-8'),
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            json_name='resourceVersion',
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key
        ),
        _descriptor.FieldDescriptor(
            name='limit',
            full_name='grid.v1.WatchDatastoresRequest.limit',
            index=1,
            number=2,
            type=3,
            cpp_type=2,
            label=1,
            has_default_value=False,
            default_value=0,
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            json_name='limit',
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key
        ),
        _descriptor.FieldDescriptor(
            name='user_id',
            full_name='grid.v1.WatchDatastoresRequest.user_id',
            index=2,
            number=4,
            type=9,
            cpp_type=9,
            label=1,
            has_default_value=False,
            default_value=b"".decode('utf-8'),
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            json_name='userId',
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key
        ),
        _descriptor.FieldDescriptor(
            name='available',
            full_name='grid.v1.WatchDatastoresRequest.available',
            index=3,
            number=5,
            type=8,
            cpp_type=7,
            label=1,
            has_default_value=False,
            default_value=False,
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            json_name='available',
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key
        ),
        _descriptor.FieldDescriptor(
            name='cluster_id',
            full_name='grid.v1.WatchDatastoresRequest.cluster_id',
            index=4,
            number=6,
            type=9,
            cpp_type=9,
            label=1,
            has_default_value=False,
            default_value=b"".decode('utf-8'),
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            json_name='clusterId',
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key
        ),
    ],
    extensions=[],
    nested_types=[],
    enum_types=[],
    serialized_options=None,
    is_extendable=False,
    syntax='proto3',
    extension_ranges=[],
    oneofs=[],
    serialized_start=1236,
    serialized_end=1411,
)

_WATCHDATASTORESRESPONSE = _descriptor.Descriptor(
    name='WatchDatastoresResponse',
    full_name='grid.v1.WatchDatastoresResponse',
    filename=None,
    file=DESCRIPTOR,
    containing_type=None,
    create_key=_descriptor._internal_create_key,
    fields=[
        _descriptor.FieldDescriptor(
            name='resource_version',
            full_name='grid.v1.WatchDatastoresResponse.resource_version',
            index=0,
            number=1,
            type=9,
            cpp_type=9,
            label=1,
            has_default_value=False,
            default_value=b"".decode('utf-8'),
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            json_name='resourceVersion',
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key
        ),
        _descriptor.FieldDescriptor(
            name='type',
            full_name='grid.v1.WatchDatastoresResponse.type',
            index=1,
            number=2,
            type=14,
            cpp_type=8,
            label=1,
            has_default_value=False,
            default_value=0,
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            json_name='type',
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key
        ),
        _descriptor.FieldDescriptor(
            name='datastore',
            full_name='grid.v1.WatchDatastoresResponse.datastore',
            index=2,
            number=3,
            type=11,
            cpp_type=10,
            label=1,
            has_default_value=False,
            default_value=None,
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            json_name='datastore',
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key
        ),
    ],
    extensions=[],
    nested_types=[],
    enum_types=[],
    serialized_options=None,
    is_extendable=False,
    syntax='proto3',
    extension_ranges=[],
    oneofs=[],
    serialized_start=1414,
    serialized_end=1577,
)

_CREATEDATASTOREREQUEST.fields_by_name['datastore'].message_type = grid_dot_v1_dot_datastore__pb2._DATASTORE
_CREATEDATASTORERESPONSE.fields_by_name['datastore'].message_type = grid_dot_v1_dot_datastore__pb2._DATASTORE
_GETDATASTORERESPONSE.fields_by_name['datastore'].message_type = grid_dot_v1_dot_datastore__pb2._DATASTORE
_LISTDATASTORESRESPONSE.fields_by_name['datastore'].message_type = grid_dot_v1_dot_datastore__pb2._DATASTORE
_UPDATEDATASTOREREQUEST.fields_by_name['datastore'].message_type = grid_dot_v1_dot_datastore__pb2._DATASTORE
_UPDATEDATASTORERESPONSE.fields_by_name['datastore'].message_type = grid_dot_v1_dot_datastore__pb2._DATASTORE
_UPDATEDATASTORESTATUSREQUEST.fields_by_name['datastore'].message_type = grid_dot_v1_dot_datastore__pb2._DATASTORE
_UPDATEDATASTORESTATUSRESPONSE.fields_by_name['datastore'].message_type = grid_dot_v1_dot_datastore__pb2._DATASTORE
_DELETEDATASTOREREQUEST.fields_by_name['datastore'].message_type = grid_dot_v1_dot_datastore__pb2._DATASTORE
_DELETEDATASTORERESPONSE.fields_by_name['datastore'].message_type = grid_dot_v1_dot_datastore__pb2._DATASTORE
_WATCHDATASTORESRESPONSE.fields_by_name['type'].enum_type = grid_dot_v1_dot_metadata__pb2._WATCHEVENTTYPE
_WATCHDATASTORESRESPONSE.fields_by_name['datastore'].message_type = grid_dot_v1_dot_datastore__pb2._DATASTORE
DESCRIPTOR.message_types_by_name['CreateDatastoreRequest'] = _CREATEDATASTOREREQUEST
DESCRIPTOR.message_types_by_name['CreateDatastoreResponse'] = _CREATEDATASTORERESPONSE
DESCRIPTOR.message_types_by_name['GetDatastoreRequest'] = _GETDATASTOREREQUEST
DESCRIPTOR.message_types_by_name['GetDatastoreResponse'] = _GETDATASTORERESPONSE
DESCRIPTOR.message_types_by_name['ListDatastoresRequest'] = _LISTDATASTORESREQUEST
DESCRIPTOR.message_types_by_name['ListDatastoresResponse'] = _LISTDATASTORESRESPONSE
DESCRIPTOR.message_types_by_name['UpdateDatastoreRequest'] = _UPDATEDATASTOREREQUEST
DESCRIPTOR.message_types_by_name['UpdateDatastoreResponse'] = _UPDATEDATASTORERESPONSE
DESCRIPTOR.message_types_by_name['UpdateDatastoreStatusRequest'] = _UPDATEDATASTORESTATUSREQUEST
DESCRIPTOR.message_types_by_name['UpdateDatastoreStatusResponse'] = _UPDATEDATASTORESTATUSRESPONSE
DESCRIPTOR.message_types_by_name['DeleteDatastoreRequest'] = _DELETEDATASTOREREQUEST
DESCRIPTOR.message_types_by_name['DeleteDatastoreResponse'] = _DELETEDATASTORERESPONSE
DESCRIPTOR.message_types_by_name['WatchDatastoresRequest'] = _WATCHDATASTORESREQUEST
DESCRIPTOR.message_types_by_name['WatchDatastoresResponse'] = _WATCHDATASTORESRESPONSE
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

CreateDatastoreRequest = _reflection.GeneratedProtocolMessageType(
    'CreateDatastoreRequest',
    (_message.Message, ),
    {
        'DESCRIPTOR': _CREATEDATASTOREREQUEST,
        '__module__': 'grid.v1.datastore_service_pb2'
        # @@protoc_insertion_point(class_scope:grid.v1.CreateDatastoreRequest)
    }
)
_sym_db.RegisterMessage(CreateDatastoreRequest)

CreateDatastoreResponse = _reflection.GeneratedProtocolMessageType(
    'CreateDatastoreResponse',
    (_message.Message, ),
    {
        'DESCRIPTOR': _CREATEDATASTORERESPONSE,
        '__module__': 'grid.v1.datastore_service_pb2'
        # @@protoc_insertion_point(class_scope:grid.v1.CreateDatastoreResponse)
    }
)
_sym_db.RegisterMessage(CreateDatastoreResponse)

GetDatastoreRequest = _reflection.GeneratedProtocolMessageType(
    'GetDatastoreRequest',
    (_message.Message, ),
    {
        'DESCRIPTOR': _GETDATASTOREREQUEST,
        '__module__': 'grid.v1.datastore_service_pb2'
        # @@protoc_insertion_point(class_scope:grid.v1.GetDatastoreRequest)
    }
)
_sym_db.RegisterMessage(GetDatastoreRequest)

GetDatastoreResponse = _reflection.GeneratedProtocolMessageType(
    'GetDatastoreResponse',
    (_message.Message, ),
    {
        'DESCRIPTOR': _GETDATASTORERESPONSE,
        '__module__': 'grid.v1.datastore_service_pb2'
        # @@protoc_insertion_point(class_scope:grid.v1.GetDatastoreResponse)
    }
)
_sym_db.RegisterMessage(GetDatastoreResponse)

ListDatastoresRequest = _reflection.GeneratedProtocolMessageType(
    'ListDatastoresRequest',
    (_message.Message, ),
    {
        'DESCRIPTOR': _LISTDATASTORESREQUEST,
        '__module__': 'grid.v1.datastore_service_pb2'
        # @@protoc_insertion_point(class_scope:grid.v1.ListDatastoresRequest)
    }
)
_sym_db.RegisterMessage(ListDatastoresRequest)

ListDatastoresResponse = _reflection.GeneratedProtocolMessageType(
    'ListDatastoresResponse',
    (_message.Message, ),
    {
        'DESCRIPTOR': _LISTDATASTORESRESPONSE,
        '__module__': 'grid.v1.datastore_service_pb2'
        # @@protoc_insertion_point(class_scope:grid.v1.ListDatastoresResponse)
    }
)
_sym_db.RegisterMessage(ListDatastoresResponse)

UpdateDatastoreRequest = _reflection.GeneratedProtocolMessageType(
    'UpdateDatastoreRequest',
    (_message.Message, ),
    {
        'DESCRIPTOR': _UPDATEDATASTOREREQUEST,
        '__module__': 'grid.v1.datastore_service_pb2'
        # @@protoc_insertion_point(class_scope:grid.v1.UpdateDatastoreRequest)
    }
)
_sym_db.RegisterMessage(UpdateDatastoreRequest)

UpdateDatastoreResponse = _reflection.GeneratedProtocolMessageType(
    'UpdateDatastoreResponse',
    (_message.Message, ),
    {
        'DESCRIPTOR': _UPDATEDATASTORERESPONSE,
        '__module__': 'grid.v1.datastore_service_pb2'
        # @@protoc_insertion_point(class_scope:grid.v1.UpdateDatastoreResponse)
    }
)
_sym_db.RegisterMessage(UpdateDatastoreResponse)

UpdateDatastoreStatusRequest = _reflection.GeneratedProtocolMessageType(
    'UpdateDatastoreStatusRequest',
    (_message.Message, ),
    {
        'DESCRIPTOR': _UPDATEDATASTORESTATUSREQUEST,
        '__module__': 'grid.v1.datastore_service_pb2'
        # @@protoc_insertion_point(class_scope:grid.v1.UpdateDatastoreStatusRequest)
    }
)
_sym_db.RegisterMessage(UpdateDatastoreStatusRequest)

UpdateDatastoreStatusResponse = _reflection.GeneratedProtocolMessageType(
    'UpdateDatastoreStatusResponse',
    (_message.Message, ),
    {
        'DESCRIPTOR': _UPDATEDATASTORESTATUSRESPONSE,
        '__module__': 'grid.v1.datastore_service_pb2'
        # @@protoc_insertion_point(class_scope:grid.v1.UpdateDatastoreStatusResponse)
    }
)
_sym_db.RegisterMessage(UpdateDatastoreStatusResponse)

DeleteDatastoreRequest = _reflection.GeneratedProtocolMessageType(
    'DeleteDatastoreRequest',
    (_message.Message, ),
    {
        'DESCRIPTOR': _DELETEDATASTOREREQUEST,
        '__module__': 'grid.v1.datastore_service_pb2'
        # @@protoc_insertion_point(class_scope:grid.v1.DeleteDatastoreRequest)
    }
)
_sym_db.RegisterMessage(DeleteDatastoreRequest)

DeleteDatastoreResponse = _reflection.GeneratedProtocolMessageType(
    'DeleteDatastoreResponse',
    (_message.Message, ),
    {
        'DESCRIPTOR': _DELETEDATASTORERESPONSE,
        '__module__': 'grid.v1.datastore_service_pb2'
        # @@protoc_insertion_point(class_scope:grid.v1.DeleteDatastoreResponse)
    }
)
_sym_db.RegisterMessage(DeleteDatastoreResponse)

WatchDatastoresRequest = _reflection.GeneratedProtocolMessageType(
    'WatchDatastoresRequest',
    (_message.Message, ),
    {
        'DESCRIPTOR': _WATCHDATASTORESREQUEST,
        '__module__': 'grid.v1.datastore_service_pb2'
        # @@protoc_insertion_point(class_scope:grid.v1.WatchDatastoresRequest)
    }
)
_sym_db.RegisterMessage(WatchDatastoresRequest)

WatchDatastoresResponse = _reflection.GeneratedProtocolMessageType(
    'WatchDatastoresResponse',
    (_message.Message, ),
    {
        'DESCRIPTOR': _WATCHDATASTORESRESPONSE,
        '__module__': 'grid.v1.datastore_service_pb2'
        # @@protoc_insertion_point(class_scope:grid.v1.WatchDatastoresResponse)
    }
)
_sym_db.RegisterMessage(WatchDatastoresResponse)

DESCRIPTOR._options = None

_DATASTORESERVICE = _descriptor.ServiceDescriptor(
    name='DatastoreService',
    full_name='grid.v1.DatastoreService',
    file=DESCRIPTOR,
    index=0,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
    serialized_start=1580,
    serialized_end=2218,
    methods=[
        _descriptor.MethodDescriptor(
            name='CreateDatastore',
            full_name='grid.v1.DatastoreService.CreateDatastore',
            index=0,
            containing_service=None,
            input_type=_CREATEDATASTOREREQUEST,
            output_type=_CREATEDATASTORERESPONSE,
            serialized_options=None,
            create_key=_descriptor._internal_create_key,
        ),
        _descriptor.MethodDescriptor(
            name='GetDatastore',
            full_name='grid.v1.DatastoreService.GetDatastore',
            index=1,
            containing_service=None,
            input_type=_GETDATASTOREREQUEST,
            output_type=_GETDATASTORERESPONSE,
            serialized_options=None,
            create_key=_descriptor._internal_create_key,
        ),
        _descriptor.MethodDescriptor(
            name='ListDatastores',
            full_name='grid.v1.DatastoreService.ListDatastores',
            index=2,
            containing_service=None,
            input_type=_LISTDATASTORESREQUEST,
            output_type=_LISTDATASTORESRESPONSE,
            serialized_options=None,
            create_key=_descriptor._internal_create_key,
        ),
        _descriptor.MethodDescriptor(
            name='UpdateDatastore',
            full_name='grid.v1.DatastoreService.UpdateDatastore',
            index=3,
            containing_service=None,
            input_type=_UPDATEDATASTOREREQUEST,
            output_type=_UPDATEDATASTORERESPONSE,
            serialized_options=None,
            create_key=_descriptor._internal_create_key,
        ),
        _descriptor.MethodDescriptor(
            name='UpdateDatastoreStatus',
            full_name='grid.v1.DatastoreService.UpdateDatastoreStatus',
            index=4,
            containing_service=None,
            input_type=_UPDATEDATASTORESTATUSREQUEST,
            output_type=_UPDATEDATASTORESTATUSRESPONSE,
            serialized_options=None,
            create_key=_descriptor._internal_create_key,
        ),
        _descriptor.MethodDescriptor(
            name='DeleteDatastore',
            full_name='grid.v1.DatastoreService.DeleteDatastore',
            index=5,
            containing_service=None,
            input_type=_DELETEDATASTOREREQUEST,
            output_type=_DELETEDATASTORERESPONSE,
            serialized_options=None,
            create_key=_descriptor._internal_create_key,
        ),
        _descriptor.MethodDescriptor(
            name='WatchDatastores',
            full_name='grid.v1.DatastoreService.WatchDatastores',
            index=6,
            containing_service=None,
            input_type=_WATCHDATASTORESREQUEST,
            output_type=_WATCHDATASTORESRESPONSE,
            serialized_options=None,
            create_key=_descriptor._internal_create_key,
        ),
    ]
)
_sym_db.RegisterServiceDescriptor(_DATASTORESERVICE)

DESCRIPTOR.services_by_name['DatastoreService'] = _DATASTORESERVICE

# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: grid/v1/whoami.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database

# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()

from grid.protos.grid.v1 import cluster_pb2 as grid_dot_v1_dot_cluster__pb2
from grid.protos.grid.v1 import user_pb2 as grid_dot_v1_dot_user__pb2

DESCRIPTOR = _descriptor.FileDescriptor(
    name='grid/v1/whoami.proto',
    package='grid.v1',
    syntax='proto3',
    serialized_options=b'Z0github.com/gridai/grid/grid-backend/apis/grid/v1',
    create_key=_descriptor._internal_create_key,
    serialized_pb=
    b'\n\x14grid/v1/whoami.proto\x12\x07grid.v1\x1a\x12grid/v1/user.proto\x1a\x15grid/v1/cluster.proto\"\x0f\n\rWhoAmIRequest\"\x8a\x01\n\x0eWhoAmIResponse\x12#\n\x04user\x18\x01 \x01(\x0b\x32\r.grid.v1.UserH\x00R\x04user\x12,\n\x07\x63luster\x18\x02 \x01(\x0b\x32\x10.grid.v1.ClusterH\x00R\x07\x63luster\x12\x1c\n\x08internal\x18\x03 \x01(\tH\x00R\x08internalB\x07\n\x05\x61\x63tor2R\n\x15\x41uthenticationService\x12\x39\n\x06WhoAmI\x12\x16.grid.v1.WhoAmIRequest\x1a\x17.grid.v1.WhoAmIResponseB2Z0github.com/gridai/grid/grid-backend/apis/grid/v1b\x06proto3',
    dependencies=[
        grid_dot_v1_dot_user__pb2.DESCRIPTOR,
        grid_dot_v1_dot_cluster__pb2.DESCRIPTOR,
    ]
)

_WHOAMIREQUEST = _descriptor.Descriptor(
    name='WhoAmIRequest',
    full_name='grid.v1.WhoAmIRequest',
    filename=None,
    file=DESCRIPTOR,
    containing_type=None,
    create_key=_descriptor._internal_create_key,
    fields=[],
    extensions=[],
    nested_types=[],
    enum_types=[],
    serialized_options=None,
    is_extendable=False,
    syntax='proto3',
    extension_ranges=[],
    oneofs=[],
    serialized_start=76,
    serialized_end=91,
)

_WHOAMIRESPONSE = _descriptor.Descriptor(
    name='WhoAmIResponse',
    full_name='grid.v1.WhoAmIResponse',
    filename=None,
    file=DESCRIPTOR,
    containing_type=None,
    create_key=_descriptor._internal_create_key,
    fields=[
        _descriptor.FieldDescriptor(
            name='user',
            full_name='grid.v1.WhoAmIResponse.user',
            index=0,
            number=1,
            type=11,
            cpp_type=10,
            label=1,
            has_default_value=False,
            default_value=None,
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            json_name='user',
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key
        ),
        _descriptor.FieldDescriptor(
            name='cluster',
            full_name='grid.v1.WhoAmIResponse.cluster',
            index=1,
            number=2,
            type=11,
            cpp_type=10,
            label=1,
            has_default_value=False,
            default_value=None,
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            json_name='cluster',
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key
        ),
        _descriptor.FieldDescriptor(
            name='internal',
            full_name='grid.v1.WhoAmIResponse.internal',
            index=2,
            number=3,
            type=9,
            cpp_type=9,
            label=1,
            has_default_value=False,
            default_value=b"".decode('utf-8'),
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            json_name='internal',
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key
        ),
    ],
    extensions=[],
    nested_types=[],
    enum_types=[],
    serialized_options=None,
    is_extendable=False,
    syntax='proto3',
    extension_ranges=[],
    oneofs=[
        _descriptor.OneofDescriptor(
            name='actor',
            full_name='grid.v1.WhoAmIResponse.actor',
            index=0,
            containing_type=None,
            create_key=_descriptor._internal_create_key,
            fields=[]
        ),
    ],
    serialized_start=94,
    serialized_end=232,
)

_WHOAMIRESPONSE.fields_by_name['user'].message_type = grid_dot_v1_dot_user__pb2._USER
_WHOAMIRESPONSE.fields_by_name['cluster'].message_type = grid_dot_v1_dot_cluster__pb2._CLUSTER
_WHOAMIRESPONSE.oneofs_by_name['actor'].fields.append(_WHOAMIRESPONSE.fields_by_name['user'])
_WHOAMIRESPONSE.fields_by_name['user'].containing_oneof = _WHOAMIRESPONSE.oneofs_by_name['actor']
_WHOAMIRESPONSE.oneofs_by_name['actor'].fields.append(_WHOAMIRESPONSE.fields_by_name['cluster'])
_WHOAMIRESPONSE.fields_by_name['cluster'].containing_oneof = _WHOAMIRESPONSE.oneofs_by_name['actor']
_WHOAMIRESPONSE.oneofs_by_name['actor'].fields.append(_WHOAMIRESPONSE.fields_by_name['internal'])
_WHOAMIRESPONSE.fields_by_name['internal'].containing_oneof = _WHOAMIRESPONSE.oneofs_by_name['actor']
DESCRIPTOR.message_types_by_name['WhoAmIRequest'] = _WHOAMIREQUEST
DESCRIPTOR.message_types_by_name['WhoAmIResponse'] = _WHOAMIRESPONSE
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

WhoAmIRequest = _reflection.GeneratedProtocolMessageType(
    'WhoAmIRequest',
    (_message.Message, ),
    {
        'DESCRIPTOR': _WHOAMIREQUEST,
        '__module__': 'grid.v1.whoami_pb2'
        # @@protoc_insertion_point(class_scope:grid.v1.WhoAmIRequest)
    }
)
_sym_db.RegisterMessage(WhoAmIRequest)

WhoAmIResponse = _reflection.GeneratedProtocolMessageType(
    'WhoAmIResponse',
    (_message.Message, ),
    {
        'DESCRIPTOR': _WHOAMIRESPONSE,
        '__module__': 'grid.v1.whoami_pb2'
        # @@protoc_insertion_point(class_scope:grid.v1.WhoAmIResponse)
    }
)
_sym_db.RegisterMessage(WhoAmIResponse)

DESCRIPTOR._options = None

_AUTHENTICATIONSERVICE = _descriptor.ServiceDescriptor(
    name='AuthenticationService',
    full_name='grid.v1.AuthenticationService',
    file=DESCRIPTOR,
    index=0,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
    serialized_start=234,
    serialized_end=316,
    methods=[
        _descriptor.MethodDescriptor(
            name='WhoAmI',
            full_name='grid.v1.AuthenticationService.WhoAmI',
            index=0,
            containing_service=None,
            input_type=_WHOAMIREQUEST,
            output_type=_WHOAMIRESPONSE,
            serialized_options=None,
            create_key=_descriptor._internal_create_key,
        ),
    ]
)
_sym_db.RegisterServiceDescriptor(_AUTHENTICATIONSERVICE)

DESCRIPTOR.services_by_name['AuthenticationService'] = _AUTHENTICATIONSERVICE

# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: grid/v1/cost_controller_service_account.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database

# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()

DESCRIPTOR = _descriptor.FileDescriptor(
    name='grid/v1/cost_controller_service_account.proto',
    package='grid.v1',
    syntax='proto3',
    serialized_options=b'Z0github.com/gridai/grid/grid-backend/apis/grid/v1',
    create_key=_descriptor._internal_create_key,
    serialized_pb=
    b'\n-grid/v1/cost_controller_service_account.proto\x12\x07grid.v1\"\x1e\n\x1c\x43ostControllerServiceAccountB2Z0github.com/gridai/grid/grid-backend/apis/grid/v1b\x06proto3'
)

_COSTCONTROLLERSERVICEACCOUNT = _descriptor.Descriptor(
    name='CostControllerServiceAccount',
    full_name='grid.v1.CostControllerServiceAccount',
    filename=None,
    file=DESCRIPTOR,
    containing_type=None,
    create_key=_descriptor._internal_create_key,
    fields=[],
    extensions=[],
    nested_types=[],
    enum_types=[],
    serialized_options=None,
    is_extendable=False,
    syntax='proto3',
    extension_ranges=[],
    oneofs=[],
    serialized_start=58,
    serialized_end=88,
)

DESCRIPTOR.message_types_by_name['CostControllerServiceAccount'] = _COSTCONTROLLERSERVICEACCOUNT
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

CostControllerServiceAccount = _reflection.GeneratedProtocolMessageType(
    'CostControllerServiceAccount',
    (_message.Message, ),
    {
        'DESCRIPTOR': _COSTCONTROLLERSERVICEACCOUNT,
        '__module__': 'grid.v1.cost_controller_service_account_pb2'
        # @@protoc_insertion_point(class_scope:grid.v1.CostControllerServiceAccount)
    }
)
_sym_db.RegisterMessage(CostControllerServiceAccount)

DESCRIPTOR._options = None
# @@protoc_insertion_point(module_scope)
